package com.hungraim.ltc.account.service.impl;

import cn.afterturn.easypoi.excel.ExcelExportUtil;
import cn.afterturn.easypoi.excel.entity.ExportParams;
import cn.afterturn.easypoi.excel.entity.enmus.ExcelType;
import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollectionUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.hungraim.ltc.account.dao.*;
import com.hungraim.ltc.account.service.AccountService;
import com.hungraim.ltc.account.service.BaseAccountService;
import com.hungraim.ltc.api.AttachFeignService;
import com.hungraim.ltc.pojo.entity.SysConfig.ChCfgCareService;
import com.hungraim.ltc.pojo.entity.SysConfig.ChCfgCostStandard;
import com.hungraim.ltc.pojo.entity.SysConfig.ChFndAttach;
import com.hungraim.ltc.pojo.entity.account.*;
import com.hungraim.ltc.pojo.entity.serviceManage.ChSrvTaskDetail;
import com.hungraim.ltc.pojo.entity.serviceManage.ChSrvTaskFinishItem;
import com.hungraim.ltc.pojo.vo.account.*;
import com.hungraim.ltc.pojo.vo.disable.PlaceOtherVO;
import com.hungraim.ltc.util.*;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.apache.poi.ss.usermodel.Workbook;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.math.BigDecimal;
import java.text.DateFormat;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.*;
import java.util.stream.Collectors;

@Service
@AllArgsConstructor
@Slf4j
public class AccountServiceImpl extends ServiceImpl<ChDisabAccountsMapper, ChDisabAccounts> implements AccountService {

    private final AttachFeignService attachFeignService;
    private final BaseAccountService baseAccountService;
    private final ChDisabAccountsMapper disabAccountsMapper;
    private final SrvTaskMapper srvTaskMapper;
    private final ChSrvTaskDetailMapper taskDetailMapper;
    private final ChSrvTaskFinishItemMapper taskFinishItemMapper;
    private final ChSrvProgramMapper programMapper;
    private final ChSrvProgramSetMapper programSetMapper;
    private final ChCfgCareServiceMapper chCfgCareServiceMapper;
    private final ChCfgCostStandardMapper chCfgCostStandardMapper;
    private final ChDisabAccountsDetailMapper chDisabAccountsDetailMapper;
    private final ChDisabFreeRdInfoMapper chDisabFreeRdInfoMapper;



    private final ChSrvTaskDetailMapper chSrvTaskDetailMapper;
    private final ChSrvTaskFinishItemMapper chSrvTaskFinishItemMapper;;




    @Override
    @Transactional(rollbackFor = Exception.class)
    public void addOrUpdateAccount(AccountOperVo accountOperVo) {
        ChDisabAccounts chDisabAccounts = new ChDisabAccounts();
        BeanUtils.copyProperties(accountOperVo, chDisabAccounts);
        chDisabAccounts.setChooseSettle((short) 0); // 是否结算(0未结算，1已结算)
        chDisabAccounts.setReviewRemark(accountOperVo.getReviewRemark());
        Short accountsStatus = accountOperVo.getAccountsStatus();
        String accountsId = String.valueOf(accountOperVo.getAccountsId());
        // 驳回
        if(accountsStatus == 0) {
            chDisabAccountsDetailMapper.updateByAccountsId(accountsId,0);
            chDisabAccounts.setAllCost(BigDecimal.valueOf(0));
            chDisabAccounts.setOverallCost(BigDecimal.valueOf(0));
            chDisabAccounts.setPersonalCost(BigDecimal.valueOf(0));
            chDisabAccounts.setReissueAmountTotal(BigDecimal.valueOf(0));
            chDisabAccounts.setDeductionAmountTotal(BigDecimal.valueOf(0));
            HashMap map = new HashMap();
            map.put("ACCOUNTS_ID",accountsId);
            chDisabFreeRdInfoMapper.deleteByMap(map);
        }
        // 已结算
        if(accountsStatus == 4) {
            ChDisabAccounts chDisabAccountDTO = disabAccountsMapper.selectById(accountOperVo.getAccountsId());
            chDisabAccountDTO.setTotalAllocatedExpenses(chDisabAccountDTO.getTotalAllocatedExpenses());
            chDisabAccountDTO.setChooseSettle((short) 1); // 是否结算(0未结算，1已结算)
            disabAccountsMapper.updateById(chDisabAccountDTO);
        }
        this.saveOrUpdate(chDisabAccounts);
        }

    @Override
    public Page<SrvOrganListResp> searchSrvOrganList(SrvOrganListReq srvOrganListReq) {
        List<Long> organIds = baseAccountService.getOrganIds(srvOrganListReq.getOrganId(), srvOrganListReq.getIsInvolveChild());
        return disabAccountsMapper.searchSrvOrganList(new Page<>(srvOrganListReq.getPageNum(), srvOrganListReq.getPageSize()), organIds, srvOrganListReq);
    }

    @Override
    public Page<SrvOrganAccountListResp> searchSrvOrganAccountList(SrvOrganListReq srvOrganListReq) {
        List<Long> organIds = baseAccountService.getOrganIds(srvOrganListReq.getOrganId(), srvOrganListReq.getIsInvolveChild());
        return disabAccountsMapper.searchSrvOrganAccountList(new Page<>(srvOrganListReq.getPageNum(), srvOrganListReq.getPageSize()), organIds, srvOrganListReq);
    }




    @Override
    public AccountOperVo getSrvOrganDetail(Long accountsId) {
        AccountOperVo accountOperVo = disabAccountsMapper.getDetailById(accountsId);
        try {
            Result<List<ChFndAttach>> result = attachFeignService.selectAttachs(accountOperVo.getAccountsId(), AttachType.SRV_ORGAN_ACCOUNT.getUploadType());
            if (ResultCode.SUCCESS.getCode().equals(result.getCode())) {
                accountOperVo.setFileDataList(result.getData());
            } else {
                log.error("获取机构结算资料失败：{}", result.getMsg());
            }
        } catch (Exception e) {
            e.printStackTrace();
            log.error("获取机构结算资料失败：{}", e.getMessage());
        }
        return accountOperVo;
    }

    @Override
    public ExpenseVo expenseSettlement(ExpenseSettlementReq req) throws ParseException {
        Page<ExpenseSettlementInfoBo> page = new Page<>(req.getPageNum(), req.getPageSize());
        //计算当前月最后一天
        DateFormat df = new SimpleDateFormat("yyyy-MM");
        Date parse = df.parse(req.getAccountsTime());
        Date lastDayOfMonth = getLastDayOfMonth(parse);
        DateFormat df2 = new SimpleDateFormat("yyyy-MM-dd");
        req.setAccountsLastDayTime(df2.format(lastDayOfMonth));
        Page<ExpenseSettlementInfoBo> expenseSettlementInfo = srvTaskMapper.getExpenseSettlementInfo(page, req);
        List<ExpenseSettlementVo> vos = new ArrayList<>();
        if (expenseSettlementInfo != null && expenseSettlementInfo.getRecords() != null) {
            for (ExpenseSettlementInfoBo bo : expenseSettlementInfo.getRecords()) {
                ExpenseSettlementVo vo = new ExpenseSettlementVo();
                BeanUtil.copyProperties(bo, vo);
                //护理等级
                vo.setNursingGrade(CfgSrvLevel.getMsg(bo.getSrvLevelId()));
                //服务开始时间
                if (bo.getSrvStartTime() != null) {
                    if (bo.getSrvStartTime().getTime() > parse.getTime()) {
                        vo.setSrvStartTime(bo.getSrvStartTime());
                    } else {
                        vo.setSrvStartTime(parse);
                    }
                }
                //服务结束时间
                if (bo.getSrvEndTime() != null) {
                    if (bo.getSrvEndTime().getTime() > lastDayOfMonth.getTime()) {
                        vo.setSrvEndTime(lastDayOfMonth);
                    } else {
                        vo.setSrvEndTime(bo.getSrvEndTime());
                    }
                }
                //有效结算日
                int startDay = getDay(vo.getSrvStartTime());
                int endDay = getDay(vo.getSrvEndTime());
                vo.setEffectiveSettlementDate(endDay - startDay + 1);
                //基护费用标准
                Integer effectiveSettlementDate = vo.getEffectiveSettlementDate();//有效结算日
                ChCfgCostStandard costStandard = chCfgCostStandardMapper.selectOne(new LambdaQueryWrapper<ChCfgCostStandard>()
                        .eq(ChCfgCostStandard::getOrganId, bo.getOrganId())
                        .eq(ChCfgCostStandard::getSrvLevelId, bo.getSrvLevelId())
                        .eq(ChCfgCostStandard::getSrvModeId, bo.getSrvModeId()));//基护费用标准(可配置)
                vo.setCostStandard(costStandard + "元/人/天");
                //基护费用
                BigDecimal foundation = BigDecimal.valueOf(costStandard.getCost()).multiply(BigDecimal.valueOf(effectiveSettlementDate));
                vo.setFoundationProtectionCost(foundation.doubleValue());
                //基护完成率
                Integer srvTaskId = bo.getSrvTaskId();
                int taskDetailsCount = taskDetailMapper.selectCount(new LambdaQueryWrapper<ChSrvTaskDetail>()//计划次数
                        .eq(ChSrvTaskDetail::getSrvTaskId, srvTaskId)
                        .in(ChSrvTaskDetail::getIllegalType, 0, 1)
                        .ne(ChSrvTaskDetail::getStatus, 3));
                List<ChSrvTaskDetail> taskDetails = taskDetailMapper.selectList(new LambdaQueryWrapper<ChSrvTaskDetail>()
                        .eq(ChSrvTaskDetail::getSrvTaskId, srvTaskId)
                        .in(ChSrvTaskDetail::getIllegalType, 0, 1)
                        .eq(ChSrvTaskDetail::getStatus, 4));
                int taskDetailsFinishCount = 0;//完成次数
                if (taskDetails != null && taskDetails.size() > 0) {
                    taskDetailsFinishCount = taskDetails.size();
                }
                int monPlanningFrequency = bo.getPlanningFrequency();//每月计划次数
                if (bo.getPlanningFrequencyType() == 1) {
                    monPlanningFrequency = bo.getPlanningFrequency();
                } else if (bo.getPlanningFrequencyType() == 2) {
                    monPlanningFrequency = bo.getPlanningFrequency() * 30;
                } else if (bo.getPlanningFrequencyType() == 3) {
                    monPlanningFrequency = bo.getPlanningFrequency() * 4;
                }
                BigDecimal divide;
                if (taskDetailsCount == 0) {
                    divide = BigDecimal.valueOf(0);
                } else {
                    divide = BigDecimal.valueOf(taskDetailsFinishCount).divide(BigDecimal.valueOf(taskDetailsCount), 2, BigDecimal.ROUND_DOWN);
                }
                BigDecimal divide1 = BigDecimal.valueOf(bo.getItemTimes()).divide(BigDecimal.valueOf(monPlanningFrequency), 2, BigDecimal.ROUND_DOWN);
                if (divide.doubleValue() > 1) {
                    divide = BigDecimal.valueOf(1);
                }
                if (divide1.doubleValue() > 1) {
                    divide1 = BigDecimal.valueOf(1);
                }
                BigDecimal comp = divide.doubleValue() == 0 ? BigDecimal.valueOf(0) : divide.multiply(divide1).setScale(4, BigDecimal.ROUND_DOWN);//基护完成率
                vo.setCompletionRateFoundationProtection(comp.doubleValue() == 0 ? "0%" : comp.multiply(BigDecimal.valueOf(100)).doubleValue() + "%");
                //巡护基护完成考核
                vo.setPatrolAndBasicProtectionCompletedAssessment("-");
                BigDecimal patrolAndBasicProtectionCompletedAssessment = BigDecimal.valueOf(0.8);//巡护基护完成考核
                if (FndSrvMode.PATROL.getCode().equals(bo.getSrvModeId())) {//巡护
                    long serviceTime = 0;//服务时长/毫秒
                    int serviceCount = 0;//服务次数
                    if (taskDetails != null && taskDetails.size() > 0) {
                        for (ChSrvTaskDetail taskDetail : taskDetails) {
                            long l = taskDetail.getSrvEndTime().getTime() - taskDetail.getSrvStartTime().getTime();
                            serviceTime += l;
                            if (l > 30 * 60 * 1000) {
                                serviceCount++;
                            }
                        }
                    }
                    long serviceTimeM = 0;
                    if (serviceTime != 0) {
                        serviceTimeM = serviceTime / (1000 * 60 * 60);//服务时长/小时
                    }
                    boolean serviceCountK = false;//服务次数考核
                    boolean serviceTimeK = false;//服务时长考核
                    if (serviceCount >= 6) {
                        serviceCountK = true;
                    }
                    if (DisableLevel.ONE.getCode().equals(bo.getDisableLevelId())) {
                        if (serviceTimeM >= 8) {
                            serviceTimeK = true;
                        }
                    } else if (DisableLevel.TWO.getCode().equals(bo.getDisableLevelId())) {
                        if (serviceTimeM >= 10) {
                            serviceTimeK = true;
                        }
                    } else if (DisableLevel.THREE.getCode().equals(bo.getDisableLevelId())) {
                        if (serviceTimeM >= 12) {
                            serviceTimeK = true;
                        }
                    }
                    if (serviceCountK && serviceTimeK) {
                        patrolAndBasicProtectionCompletedAssessment = BigDecimal.valueOf(1);
                        vo.setPatrolAndBasicProtectionCompletedAssessment("100%");
                    } else if (serviceCountK || serviceTimeK) {
                        patrolAndBasicProtectionCompletedAssessment = BigDecimal.valueOf(0.9);
                        vo.setPatrolAndBasicProtectionCompletedAssessment("90%");
                    } else {
                        vo.setPatrolAndBasicProtectionCompletedAssessment("80%");
                    }
                }
                //基护应拨费用
                BigDecimal foundationProtectionCost = BigDecimal.valueOf(vo.getFoundationProtectionCost());//基护费用
                if (FndSrvMode.PATROL.getCode().equals(bo.getSrvModeId())) {//巡护
                    BigDecimal multiply = foundationProtectionCost.multiply(comp).multiply(patrolAndBasicProtectionCompletedAssessment).multiply(BigDecimal.valueOf(0.9)).setScale(2, BigDecimal.ROUND_DOWN);
                    vo.setExpensesPayableFoundationProtection(multiply.doubleValue());
                } else if (FndSrvMode.HOME_CARE.getCode().equals(bo.getSrvModeId())
                        || FndSrvMode.HOSPITAL_NURSING.getCode().equals(bo.getSrvModeId())) {//家护/院护
                    BigDecimal multiply = foundationProtectionCost.multiply(comp).multiply(BigDecimal.valueOf(0.9)).setScale(2, BigDecimal.ROUND_DOWN);
                    vo.setExpensesPayableFoundationProtection(multiply.doubleValue());
                }
                //照护费用标准
                int standardCareCost = 0;
                if (CfgSrvLevel.ONE.getCode().equals(bo.getSrvLevelId())) {//服务等级
                    standardCareCost = 25;
                    vo.setStandardCareCost("25元/人/天");
                } else if (CfgSrvLevel.TWO.getCode().equals(bo.getSrvLevelId())) {
                    standardCareCost = 35;
                    vo.setStandardCareCost("35元/人/天");
                } else if (CfgSrvLevel.THREE.getCode().equals(bo.getSrvLevelId())) {
                    standardCareCost = 45;
                    vo.setStandardCareCost("45元/人/天");
                }
                //照护费用
                List<ChSrvTaskDetail> taskDetails2 = taskDetailMapper.selectList(new LambdaQueryWrapper<ChSrvTaskDetail>()
                        .eq(ChSrvTaskDetail::getSrvTaskId, srvTaskId)
                        .in(ChSrvTaskDetail::getIllegalType, 0, 2)
                        .eq(ChSrvTaskDetail::getStatus, 4));
                BigDecimal careCosts = BigDecimal.valueOf(0);
                int taskDetailsFinishCount2 = 0;
                if (taskDetails2 != null && taskDetails2.size() > 0) {
                    taskDetailsFinishCount2 = taskDetails2.size();
                    careCosts = BigDecimal.valueOf(standardCareCost).multiply(BigDecimal.valueOf(taskDetails2.size()));
                }
                if (FndSrvMode.PATROL.getCode().equals(bo.getSrvModeId())) {//巡护
                    ChCfgCareService chCfgCareService = chCfgCareServiceMapper.selectOne(new LambdaQueryWrapper<ChCfgCareService>()
                            .eq(ChCfgCareService::getSrvlevelId, bo.getSrvLevelId()));//根据服务等级查询照护服务费用限额配置表
                    if (chCfgCareService != null) {
                        if (careCosts.intValue() > chCfgCareService.getMonthlyPaymentLimit()) {
                            careCosts = BigDecimal.valueOf(chCfgCareService.getMonthlyPaymentLimit());
                        }
                    }
                }
                vo.setCareCosts(careCosts.doubleValue());
                //照护完成率
                int taskDetailsCount2 = taskDetailMapper.selectCount(new LambdaQueryWrapper<ChSrvTaskDetail>()//计划次数
                        .eq(ChSrvTaskDetail::getSrvTaskId, srvTaskId)
                        .in(ChSrvTaskDetail::getIllegalType, 0, 2)
                        .ne(ChSrvTaskDetail::getStatus, 3));
                BigDecimal divide2;
                if (taskDetailsCount2 == 0) {
                    divide2 = BigDecimal.valueOf(0);
                } else {
                    divide2 = BigDecimal.valueOf(taskDetailsFinishCount2).divide(BigDecimal.valueOf(taskDetailsCount2), 2, BigDecimal.ROUND_DOWN);
                }
                BigDecimal divide3 = BigDecimal.valueOf(bo.getItemTimes()).divide(BigDecimal.valueOf(monPlanningFrequency), 2, BigDecimal.ROUND_DOWN);
                if (divide2.doubleValue() > 1) {
                    divide2 = BigDecimal.valueOf(1);
                }
                if (divide3.doubleValue() > 1) {
                    divide3 = BigDecimal.valueOf(1);
                }
                BigDecimal comp2 = divide2.doubleValue() == 0 ? BigDecimal.valueOf(0) : divide2.multiply(divide3).setScale(4, BigDecimal.ROUND_DOWN);//照护完成率
                vo.setCareCompletionRate(comp2.doubleValue() == 0 ? "0%" : comp2.multiply(BigDecimal.valueOf(100)).doubleValue() + "%");
                //巡护照护完成考核
                vo.setPatrolCareCompletionAssessment("-");
                BigDecimal patrolCareCompletionAssessment = BigDecimal.valueOf(0.8);//巡护照护完成考核
                if (FndSrvMode.PATROL.getCode().equals(bo.getSrvModeId())) {//巡护
                    long serviceTime = 0;//服务时长/毫秒
                    int serviceCount = 0;//服务次数
                    if (taskDetails2 != null && taskDetails2.size() > 0) {
                        for (ChSrvTaskDetail taskDetail : taskDetails2) {
                            long l = taskDetail.getSrvEndTime().getTime() - taskDetail.getSrvStartTime().getTime();
                            serviceTime += l;
                            if (l > 30 * 60 * 1000) {
                                serviceCount++;
                            }
                        }
                    }
                    long serviceTimeM = 0;
                    if (serviceTime != 0) {
                        serviceTimeM = serviceTime / (1000 * 60 * 60);//服务时长/小时
                    }
                    boolean serviceCountK = false;//服务次数考核
                    boolean serviceTimeK = false;//服务时长考核
                    if (serviceCount >= 6) {
                        serviceCountK = true;
                    }
                    if (DisableLevel.ONE.getCode().equals(bo.getDisableLevelId())) {
                        if (serviceTimeM >= 8) {
                            serviceTimeK = true;
                        }
                    } else if (DisableLevel.TWO.getCode().equals(bo.getDisableLevelId())) {
                        if (serviceTimeM >= 10) {
                            serviceTimeK = true;
                        }
                    } else if (DisableLevel.THREE.getCode().equals(bo.getDisableLevelId())) {
                        if (serviceTimeM >= 12) {
                            serviceTimeK = true;
                        }
                    }
                    if (serviceCountK && serviceTimeK) {
                        patrolCareCompletionAssessment = BigDecimal.valueOf(1);
                        vo.setPatrolCareCompletionAssessment("100%");
                    } else if (serviceCountK || serviceTimeK) {
                        patrolCareCompletionAssessment = BigDecimal.valueOf(0.9);
                        vo.setPatrolCareCompletionAssessment("90%");
                    } else {
                        vo.setPatrolCareCompletionAssessment("80%");
                    }
                }
                //照护应拨费用
                if (FndSrvMode.PATROL.getCode().equals(bo.getSrvModeId())) {//巡护
                    BigDecimal multiply = careCosts.multiply(comp2).multiply(patrolCareCompletionAssessment).multiply(BigDecimal.valueOf(0.9)).setScale(2, BigDecimal.ROUND_DOWN);
                    vo.setCarePayable(multiply.doubleValue());
                } else if (FndSrvMode.HOME_CARE.getCode().equals(bo.getSrvModeId())
                        || FndSrvMode.HOSPITAL_NURSING.getCode().equals(bo.getSrvModeId())) {//家护/院护
                    BigDecimal multiply = careCosts.multiply(comp2).multiply(BigDecimal.valueOf(0.9)).setScale(2, BigDecimal.ROUND_DOWN);
                    vo.setCarePayable(multiply.doubleValue());
                }
                //应拨付总金额
                vo.setTotalAmountDue(BigDecimal.valueOf(vo.getExpensesPayableFoundationProtection()).add(BigDecimal.valueOf(vo.getCarePayable())).doubleValue());
                vos.add(vo);
            }
            //合计
            ExpenseSettlementTotalVo totalVo = new ExpenseSettlementTotalVo();
            BigDecimal foundationProtectionCost = BigDecimal.valueOf(0);
            BigDecimal expensesPayableFoundationProtection = BigDecimal.valueOf(0);
            BigDecimal careCosts = BigDecimal.valueOf(0);
            BigDecimal carePayable = BigDecimal.valueOf(0);
            BigDecimal totalAmountDue = BigDecimal.valueOf(0);
            for (ExpenseSettlementVo vo : vos) {
                //基护费用
                foundationProtectionCost = foundationProtectionCost.add(BigDecimal.valueOf(vo.getFoundationProtectionCost()));
                //基护应拨费用
                expensesPayableFoundationProtection = expensesPayableFoundationProtection.add(BigDecimal.valueOf(vo.getExpensesPayableFoundationProtection()));
                //照护费用
                careCosts = careCosts.add(BigDecimal.valueOf(vo.getCareCosts()));
                //照护应拨费用
                carePayable = carePayable.add(BigDecimal.valueOf(vo.getCarePayable()));
                //应拨付总金额
                totalAmountDue = totalAmountDue.add(BigDecimal.valueOf(vo.getTotalAmountDue()));
            }
            totalVo.setFoundationProtectionCost(foundationProtectionCost.doubleValue());
            totalVo.setExpensesPayableFoundationProtection(expensesPayableFoundationProtection.doubleValue());
            totalVo.setCareCosts(careCosts.doubleValue());
            totalVo.setCarePayable(carePayable.doubleValue());
            totalVo.setTotalAmountDue(totalAmountDue.doubleValue());
            ExpenseVo expenseVo = new ExpenseVo();
            expenseVo.setTotal(expenseSettlementInfo.getTotal());
            expenseVo.setCurrent(expenseSettlementInfo.getCurrent());
            expenseVo.setSize(expenseSettlementInfo.getSize());
            expenseVo.setExpenseSettlements(vos);
            expenseVo.setTotalVo(totalVo);
            return expenseVo;
        }
        return new ExpenseVo();
    }

    //求当月最后一天
    private  Date getLastDayOfMonth(Date date) {
        Calendar cale = Calendar.getInstance();
        cale.setTime(date);
        cale.add(Calendar.MONTH, 1);
        cale.set(Calendar.DAY_OF_MONTH, 0);
        return cale.getTime();
    }




    //求年月日中的日
    private int getDay(Date date) {
        Calendar cale = Calendar.getInstance();
        cale.setTime(date);
        return cale.get(Calendar.DAY_OF_MONTH);
    }













    @Override
    public Workbook srvOrganAccountExport(SrvOrganListReq req) {
        List<AccountExportDetailListResp> srvOrganAccountExportList = chDisabAccountsDetailMapper.searchSrvOrganAccountDetailExport(req);
        ExportParams exportParams = new ExportParams();
        exportParams.setType(ExcelType.XSSF);    //对应xlsx
        Workbook workbook = ExcelExportUtil.exportExcel(exportParams, AccountExportDetailListResp.class, srvOrganAccountExportList);
        return workbook;
    }


    @Override
    public Page<ChDisabDetailAccountsResp> queryOrganAccountsDetail(Integer pageNum, Integer pageSize,SrvOrganListReq srvOrganListReq) {
        return chDisabAccountsDetailMapper.queryOrganAccountsDetail(new Page<>(pageNum, pageSize),srvOrganListReq);
    }




    @Override
    public Page<NursingRecordsRespVO> queryNursingRecords(NursingReqVO nursingReqVO) {
        String modeName = nursingReqVO.getModeName();
        Page<NursingRecordsRespVO> nursingRecordsRespVOPage = null;
        if("上门".equals(modeName)){
            nursingRecordsRespVOPage = chDisabAccountsDetailMapper.queryNursingRecordsGoDoor(new Page<>(nursingReqVO.getPageNum(), nursingReqVO.getPageSize()), nursingReqVO);
        }else {
            nursingReqVO.setModeId("医疗".equals(modeName) ? "1" : "2");
            nursingRecordsRespVOPage = chDisabAccountsDetailMapper.queryNursingRecords(new Page<>(nursingReqVO.getPageNum(), nursingReqVO.getPageSize()), nursingReqVO);
        }
        return nursingRecordsRespVOPage;
    }

    @Override
    public OverallEduceDecreaseCostRespVO queryOverallCostRecords(OverallCostReqVO req) {
        return chDisabAccountsDetailMapper.queryOverallCostRecords(req);
    }


    @Override
    public Page<OverallCostListRespVO> queryFreeRdInfo(OverallCostReqVO req) {
        req.setDealType((null == req.getDealType() || 0 == req.getDealType()) ? null : req.getDealType());
        Page<OverallCostListRespVO> overallCostListRespVOPage = chDisabFreeRdInfoMapper.queryFreeRdInfo(new Page<>(req.getPageNum(), req.getPageSize()), req);
        return overallCostListRespVOPage;
    }

    @Override
    public int overallCostSubmit(OverallCostSubmitReqVO req){
        ChDisabDetailAccounts chDisabDetailAccounts = new ChDisabDetailAccounts();
        int dealType = req.getDealType();
        Long accountsDetailId = req.getAccountsDetailId();
        chDisabDetailAccounts.setAccountsDetailId(accountsDetailId);
        Long accountsId = req.getAccountsId();
        ChDisabAccounts chDisabAccounts = disabAccountsMapper.selectById(accountsId);
        ChDisabDetailAccounts chDisabDetailAccountsDTO = chDisabAccountsDetailMapper.selectById(accountsDetailId);
        BigDecimal deductionAmount = chDisabDetailAccountsDTO.getDeductionAmount();
        BigDecimal reissueAmount = chDisabDetailAccountsDTO.getReissueAmount();
        BigDecimal deductionAmountTotal = chDisabAccounts.getDeductionAmountTotal();
        BigDecimal reissueAmountTotal = chDisabAccounts.getReissueAmountTotal();
        chDisabDetailAccounts.setDealType(dealType);
        String amountOfMoneyStr = req.getAmountOfMoney();
        BigDecimal amountOfMoney = new BigDecimal(amountOfMoneyStr);
        if(dealType == 1){
            // 补发
            chDisabDetailAccounts.setReissueAmount(reissueAmount.add(amountOfMoney));
            reissueAmountTotal = reissueAmountTotal.add(amountOfMoney);
        }else if(dealType == 2){
            // 扣减
            chDisabDetailAccounts.setDeductionAmount(deductionAmount.add(amountOfMoney));
            deductionAmountTotal = deductionAmountTotal.add(amountOfMoney);
        }
        int result = chDisabAccountsDetailMapper.updateById(chDisabDetailAccounts);
        chDisabAccounts.setReissueAmountTotal(reissueAmountTotal);
        chDisabAccounts.setDeductionAmountTotal(deductionAmountTotal);
        disabAccountsMapper.updateById(chDisabAccounts);
        ChDisabFreeRdInfo chDisabFreeRdInfo = new ChDisabFreeRdInfo();
        chDisabFreeRdInfo.setDealType(dealType);
        chDisabFreeRdInfo.setAmountOfMoney(amountOfMoney);
        chDisabFreeRdInfo.setAccountsDetailId(accountsDetailId);
        chDisabFreeRdInfo.setAccountsId(accountsId);
        chDisabFreeRdInfo.setCreationTime(new Date());
        chDisabFreeRdInfo.setRemarks(req.getRemarks());
        chDisabFreeRdInfoMapper.insert(chDisabFreeRdInfo);
        return result;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public int updateChDisabAccounts(int id) {
        ChDisabAccounts ca = new ChDisabAccounts();
        ca.setAccountsId(Long.valueOf(id));
        ca.setAccountsStatus((short) 2);
        return disabAccountsMapper.updateById(ca);


    }



    @Override
    public Page<SrvTaskRespVO> getSrvTaskList(SrvTaskReqVO srvTaskReqVO){
        Page<SrvTaskRespVO> srvTaskList = taskDetailMapper.getSrvTaskList(new Page<>(srvTaskReqVO.getPageNum(), srvTaskReqVO.getPageSize()),  srvTaskReqVO);
        return srvTaskList;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public Result accountTaskExecute(List<AccountTaskExecuteReqVO> accountTaskExecuteReqVOS) {
        log.info("organAccountTaskExecute.accountTaskExecuteReqVOS:{}",accountTaskExecuteReqVOS);
        if (CollectionUtil.isEmpty(accountTaskExecuteReqVOS)) {
            return Result.failed("参数不能为空");
        }
        // 根据任务id分组，一个任务下会有多个项目，任务id相同
        Map<String, List<AccountTaskExecuteReqVO>> accountTaskMap = accountTaskExecuteReqVOS.stream().collect(Collectors.groupingBy(AccountTaskExecuteReqVO::getTaskDetailId));
        for(Map.Entry<String, List<AccountTaskExecuteReqVO>> entry:accountTaskMap.entrySet()) {
            String taskDetailId = entry.getKey();
            // 已完成的任务,一个任务下有服务完成就产生结算，多个服务完成算一条服务的结算（实际上结算详情有一条记录就产生结算费用）
            List<AccountTaskExecuteReqVO> accountTaskList = entry.getValue();
            // 处理具体的服务项目
            try {

                List<ChSrvTaskFinishItem> chSrvTaskFinishItems = chSrvTaskFinishItemMapper.selectList(new LambdaQueryWrapper<ChSrvTaskFinishItem>()
                        .eq(ChSrvTaskFinishItem::getTaskDetailId, taskDetailId));

                for (AccountTaskExecuteReqVO accountTaskExecuteReqVO : accountTaskList) {
                    // 已申报的任务不允许再执行任务

                    String srvDateYm = DateUtils.dateToStrYm(DateUtils.strToDate(accountTaskExecuteReqVO.getSrvDate()));
                    accountTaskExecuteReqVO.setSrvDateYm(srvDateYm);
                    int count = chDisabAccountsDetailMapper.selectByCondition(accountTaskExecuteReqVO);
                    if(count>0){
                        return Result.failed("此任务已提交申报，不可再操作，请联系管理员");
                    }
                    // 已完成的任务更新ch_srv_plan状态
                    String planId = accountTaskExecuteReqVO.getPlanId();
                    Integer integer = chSrvTaskDetailMapper.updateSrvPlanById(planId);
                    if(integer == 0) {
                        log.info("更新任务计划表失败");
                    }


                    List<ChSrvTaskFinishItem> chSrvTaskFinishItemStream = chSrvTaskFinishItems.stream()
                            .filter(s -> s.getItemId().equals(Long.valueOf(accountTaskExecuteReqVO.getItemId()))).collect(Collectors.toList());
                    // 如果存在就不插入了
                    if (CollectionUtil.isNotEmpty(chSrvTaskFinishItemStream)) {
                        continue;
                    }

                ChSrvTaskFinishItem chSrvTaskFinishItem = new ChSrvTaskFinishItem();
                chSrvTaskFinishItem.setTaskDetailId(Long.valueOf(accountTaskExecuteReqVO.getTaskDetailId()));
                chSrvTaskFinishItem.setItemId(Long.valueOf(accountTaskExecuteReqVO.getItemId()));
                chSrvTaskFinishItemMapper.insert(chSrvTaskFinishItem);

                }
                accountSave1(taskDetailId,accountTaskList);
            } catch (Exception e) {
                log.info("=====accountSave error:{}",e);
                return Result.failed("服务异常");
            }
        }
        return Result.success();
    }


    private void accountSave1(String taskDetailId,List<AccountTaskExecuteReqVO> accountTaskList) {
        // 已完成任务 已结算
        List<OrganAccountsVO> accountsList = chDisabAccountsDetailMapper.queryPlanInfoByDetailId(taskDetailId);
        if (CollectionUtil.isNotEmpty(accountsList)) {
            return;
        }
        ChSrvTaskDetail ca = new ChSrvTaskDetail();
        ca.setStatus((short) 4);
        ca.setTaskDetailId(Long.valueOf(taskDetailId));
        chSrvTaskDetailMapper.updateById(ca);
            AccountTaskExecuteReqVO accountsVO = accountTaskList.get(0);
            ChDisabDetailAccounts chDisabDetailAccounts = new ChDisabDetailAccounts();
            String srvOrganId = accountsVO.getSrvOrganId();
            // 结算时间为任务时间
            Date accountsTime = DateUtils.strToDate(accountsVO.getSrvDate());
            String disabInfoId = accountsVO.getDisabInfoId();
            //要判断是养老还是医疗，因为费用不一样
            BigDecimal limit = BigDecimal.valueOf(0);
            BigDecimal overallPercent = BigDecimal.valueOf(0.7);
            BigDecimal personalPercent = BigDecimal.valueOf(0.3);
            String srvModeName = accountsVO.getSrvModeName();
            // 养老机构护理，其限额为 50 元/人/天  由长期护理保险基金支付 70% 个人支付 30%
            if ("养老".equals(srvModeName)) {
                limit = BigDecimal.valueOf(50);
                //  医疗机构护理，原则上收治医疗护理需求为主的重度失能人员一级及以下医疗机构其限额为 80 元/人/天，由长期护理保险基金支付 70%，个人支付 30%;
            } else if ("医疗".equals(srvModeName) && "1".equals(accountsVO.getLevelCode())) {
                limit = BigDecimal.valueOf(80);
                // 二级及以上医疗机构其限额为 100 元/人/天,由长期护理保险基金支付 70%，个人支付 30%;
            } else if ("医疗".equals(srvModeName) && (!"1".equals(accountsVO.getLevelCode()))) {
                limit = BigDecimal.valueOf(100);
            }
            // 根据护理机构、结算月份、失能人员id和服务方式查询表里是否有值
            ChDisabDetailAccounts chDisabDetailAccountsDTO = chDisabAccountsDetailMapper.queryDisabDetailAccounts(srvOrganId, DateUtils.dateToStrYm(accountsTime), disabInfoId, srvModeName);
            BigDecimal overallCost = limit.multiply(overallPercent);
            BigDecimal personalCost = limit.multiply(personalPercent);
            if(Objects.isNull(chDisabDetailAccountsDTO)){
                chDisabDetailAccounts.setAccountsAllCost(limit);
                chDisabDetailAccounts.setAccountsOverallCost(overallCost);
                chDisabDetailAccounts.setAccountsPersonalCost(personalCost);
                chDisabDetailAccounts.setModeName(accountsVO.getSrvModeName());
                chDisabDetailAccounts.setSrvOrganId(srvOrganId);
                chDisabDetailAccounts.setEmpId(accountsVO.getEmpId());
                chDisabDetailAccounts.setCreationTime(new Date());
                chDisabDetailAccounts.setAccountsTime(accountsTime);
                chDisabDetailAccounts.setAccountsStartTime(DateUtils.getFirstDayOfMonth(DateUtils.strToDate(accountsVO.getSrvDate())));
                chDisabDetailAccounts.setAccountsEndTime(DateUtils.getlastDayOfMonth(DateUtils.strToDate(accountsVO.getSrvDate())));
                chDisabDetailAccounts.setMedicalArea(accountsVO.getMedicalArea());
                chDisabDetailAccounts.setDisabInfoId(disabInfoId);
                chDisabDetailAccounts.setStatus((short)0);
                chDisabDetailAccounts.setReissueAmount(BigDecimal.valueOf(0));
                chDisabDetailAccounts.setDeductionAmount(BigDecimal.valueOf(0));
                ChDisabAccounts chDisabAccounts = getChDisabAccounts1(accountsVO);
                chDisabDetailAccounts.setAccountsId(chDisabAccounts.getAccountsId());
                chDisabAccountsDetailMapper.insert(chDisabDetailAccounts);
            }else {
                BigDecimal accountsAllCost = chDisabDetailAccountsDTO.getAccountsAllCost();
                BigDecimal accountsOverallCost = chDisabDetailAccountsDTO.getAccountsOverallCost();
                BigDecimal accountsPersonalCost = chDisabDetailAccountsDTO.getAccountsPersonalCost();
                chDisabDetailAccountsDTO.setAccountsAllCost(accountsAllCost.add(limit));
                chDisabDetailAccountsDTO.setAccountsOverallCost(accountsOverallCost.add(overallCost));
                chDisabDetailAccountsDTO.setAccountsPersonalCost(accountsPersonalCost.add(personalCost));
                chDisabAccountsDetailMapper.updateById(chDisabDetailAccountsDTO);
            }

    }


    private ChDisabAccounts getChDisabAccounts1(AccountTaskExecuteReqVO accountsVO) {
        // 结算表  根据机构和结算时间  服务方式
        ChDisabAccounts chDisabAccounts = disabAccountsMapper.queryAccountByCondition(DateUtils.dateToStrYm(DateUtils.strToDate(accountsVO.getSrvDate())), accountsVO.getSrvModeName(), accountsVO.getSrvOrganId(),null);
        if(chDisabAccounts == null) {
            chDisabAccounts = new ChDisabAccounts();
            chDisabAccounts.setModeName(accountsVO.getSrvModeName());
            chDisabAccounts.setAccountsTime(DateUtils.strToDateMd(accountsVO.getSrvDate()));
            chDisabAccounts.setSrvOrganId(Long.valueOf(accountsVO.getSrvOrganId()));
            chDisabAccounts.setCreationTime(new Date());
            chDisabAccounts.setAccountsStatus((short) 0);
            BigDecimal zero = BigDecimal.valueOf(0);
            chDisabAccounts.setAllCost(zero);
            chDisabAccounts.setOverallCost(zero);
            chDisabAccounts.setPersonalCost(zero);
            chDisabAccounts.setReissueAmountTotal(zero);
            chDisabAccounts.setDeductionAmountTotal(zero);
            disabAccountsMapper.insert(chDisabAccounts);
        }
        return chDisabAccounts;
    }


        @Override
        public void otherPlaceHandler(String programId){
   /*      List<OrganAccountsVO> accountsList = chDisabAccountsDetailMapper.getOtherPlaceList(programId);
          for (OrganAccountsVO accountsVO : accountsList) {
            ChDisabDetailAccounts chDisabDetailAccounts  = new ChDisabDetailAccounts();
            chDisabDetailAccounts.setSrvOrganId(accountsVO.getSrvOrganId());
            // 异地
            BigDecimal limit = BigDecimal.valueOf(20);
            BigDecimal zero = BigDecimal.valueOf(0);
            chDisabDetailAccounts.setAccountsAllCost(limit);
            chDisabDetailAccounts.setAccountsPersonalCost(zero);
            chDisabDetailAccounts.setAccountsOverallCost(zero);
            chDisabDetailAccounts.setReissueAmount(zero);
            chDisabDetailAccounts.setDeductionAmount(zero);
            chDisabDetailAccounts.setStatus((short)0);
            chDisabDetailAccounts.setModeName(accountsVO.getSrvModeName());
            chDisabDetailAccounts.setCreationTime(new Date());
            chDisabDetailAccounts.setAccountsTime(DateUtils.strToDate(accountsVO.getSrvDate()));
            chDisabDetailAccounts.setAccountsStartTime(DateUtils.getFirstDayOfMonth(DateUtils.strToDate(accountsVO.getSrvDate())));
            chDisabDetailAccounts.setAccountsEndTime(DateUtils.getlastDayOfMonth(DateUtils.strToDate(accountsVO.getSrvDate())));
            chDisabDetailAccounts.setTaskDetailId(accountsVO.getTaskDetailId());
            chDisabDetailAccounts.setMedicalArea(accountsVO.getMedicalArea());
            chDisabDetailAccounts.setDisabInfoId(accountsVO.getDisabInfoId());
            ChDisabAccounts chDisabAccounts = getChDisabAccounts1(accountsVO);
            chDisabDetailAccounts.setAccountsId(chDisabAccounts.getAccountsId());
            chDisabAccountsDetailMapper.insert(chDisabDetailAccounts);
        }*/
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public int deleteAccountsDetail(Long accountsDetailId,Long freeRdId){
        ChDisabFreeRdInfo chDisabFreeRdInfo = chDisabFreeRdInfoMapper.selectById(freeRdId);
        BigDecimal amountOfMoney = chDisabFreeRdInfo.getAmountOfMoney();
        int freeDealType = chDisabFreeRdInfo.getDealType();
        ChDisabDetailAccounts chDisabDetailAccountsDTO = chDisabAccountsDetailMapper.selectById(accountsDetailId);
        BigDecimal deductionAmount = chDisabDetailAccountsDTO.getDeductionAmount();
        BigDecimal reissueAmount = chDisabDetailAccountsDTO.getReissueAmount();
        Long accountsId = chDisabDetailAccountsDTO.getAccountsId();
        ChDisabAccounts chDisabAccountDTO = disabAccountsMapper.selectById(accountsId);
        BigDecimal reissueAmountTotal = chDisabAccountDTO.getReissueAmountTotal();
        BigDecimal deductionAmountTotal = chDisabAccountDTO.getDeductionAmountTotal();
        if (freeDealType == 1) {
            // 删除减掉补发
            BigDecimal reissueAmountSubtract = reissueAmountTotal.subtract(amountOfMoney);
            chDisabAccountDTO.setReissueAmountTotal(reissueAmountSubtract);
            BigDecimal subtract = reissueAmount.subtract(amountOfMoney);
            chDisabDetailAccountsDTO.setReissueAmount(subtract);
        } else if (freeDealType == 2) {
            // 删除减掉扣减
            BigDecimal deductionAmountSubtract = deductionAmountTotal.subtract(amountOfMoney);
            chDisabAccountDTO.setDeductionAmountTotal(deductionAmountSubtract);
            BigDecimal subtract = deductionAmount.subtract(amountOfMoney);
            chDisabDetailAccountsDTO.setDeductionAmount(subtract);
        }
        disabAccountsMapper.updateById(chDisabAccountDTO);
        int result = chDisabAccountsDetailMapper.updateById(chDisabDetailAccountsDTO);
        chDisabFreeRdInfoMapper.deleteById(freeRdId);
        return result;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public int accountsFreeCommit(Long accountsDetailId){
        ChDisabDetailAccounts chDisabDetailAccountsDTO = chDisabAccountsDetailMapper.selectById(accountsDetailId);
        BigDecimal allCost = chDisabDetailAccountsDTO.getAccountsAllCost();
        BigDecimal overallCost  = chDisabDetailAccountsDTO.getAccountsOverallCost();
        BigDecimal personalCost = chDisabDetailAccountsDTO.getAccountsPersonalCost();
        Long accountsId = chDisabDetailAccountsDTO.getAccountsId();
        ChDisabAccounts chDisabAccountDTO = disabAccountsMapper.selectById(accountsId);
        Short accountsStatus = chDisabAccountDTO.getAccountsStatus();
        if(accountsStatus > 1){
            log.info("{},已完成审核",accountsDetailId);
            return -1;
        }

        if(chDisabAccountDTO !=null){
            BigDecimal accountAllCost = chDisabAccountDTO.getAllCost();
            BigDecimal accountOverallCost = chDisabAccountDTO.getOverallCost();
            BigDecimal accountPersonalCost = chDisabAccountDTO.getPersonalCost();
            chDisabAccountDTO.setAllCost(accountAllCost.add(allCost));
            chDisabAccountDTO.setOverallCost(accountOverallCost.add(overallCost));
            chDisabAccountDTO.setPersonalCost(accountPersonalCost.add(personalCost));
            chDisabAccountDTO.setAccountsStatus((short)1);
            disabAccountsMapper.updateById(chDisabAccountDTO);
        }
        ChDisabDetailAccounts chDisabDetailAccounts = new ChDisabDetailAccounts();
        chDisabDetailAccounts.setAccountsDetailId(accountsDetailId);
        chDisabDetailAccounts.setStatus(((short)1));
        chDisabDetailAccounts.setDeclarationTime(new Date());
        int result = chDisabAccountsDetailMapper.updateById(chDisabDetailAccounts);
        return result;
    }


    @Override
    public int delayAccountCommit(Long accountsDetailId,Short status){
        // 暂缓需要将当月的钱减掉
        ChDisabDetailAccounts chDisabDetailAccountDTO = chDisabAccountsDetailMapper.selectById(accountsDetailId);
        Long accountsId = chDisabDetailAccountDTO.getAccountsId();
        BigDecimal accountsAllCost = chDisabDetailAccountDTO.getAccountsAllCost();
        BigDecimal accountsOverallCost = chDisabDetailAccountDTO.getAccountsOverallCost();
        BigDecimal accountsPersonalCost = chDisabDetailAccountDTO.getAccountsPersonalCost();
        BigDecimal deductionAmount = chDisabDetailAccountDTO.getDeductionAmount();
        BigDecimal reissueAmount = chDisabDetailAccountDTO.getReissueAmount();
        ChDisabAccounts chDisabAccountDTO = disabAccountsMapper.selectById(accountsId);
        BigDecimal allCost = chDisabAccountDTO.getAllCost();
        BigDecimal overallCost = chDisabAccountDTO.getOverallCost();
        BigDecimal personalCost = chDisabAccountDTO.getPersonalCost();
        BigDecimal deductionAmountTotal = chDisabAccountDTO.getDeductionAmountTotal();
        BigDecimal reissueAmountTotal = chDisabAccountDTO.getReissueAmountTotal();
        Short accountsStatus = chDisabAccountDTO.getAccountsStatus();
        if (accountsStatus > 1) {
            log.info("{},已完成审核",accountsDetailId);
            return -1;
        }
        // 暂缓
        if(status == 2){
            allCost = allCost.subtract(accountsAllCost);
            overallCost = overallCost.subtract(accountsOverallCost);
            personalCost = personalCost.subtract(accountsPersonalCost);
            BigDecimal deductionAmountTotalSub = deductionAmountTotal.subtract(deductionAmount);
            BigDecimal reissueAmountTotalSub = reissueAmountTotal.subtract(reissueAmount);
            ChDisabAccounts chDisabAccount = new ChDisabAccounts();
            chDisabAccount.setAllCost(allCost);
            chDisabAccount.setOverallCost(overallCost);
            chDisabAccount.setPersonalCost(personalCost);
            chDisabAccount.setAccountsId(accountsId);
            chDisabAccount.setDeductionAmountTotal(deductionAmountTotalSub);
            chDisabAccount.setReissueAmountTotal(reissueAmountTotalSub);
            disabAccountsMapper.updateById(chDisabAccount);
            // 恢复
        }else if(status == 1){
            // 判断恢复时间是否和之前结算时间在同一个月，如果在同一个月把金额加回来，如果不在同一个月，改变结算月份,恢复的时候重新插入一条
            //结算记录
            Date accountsTime = chDisabDetailAccountDTO.getAccountsTime();
            Boolean aBoolean = DateUtils.inCurrentMonth(accountsTime);
            //  同一个月
            if(aBoolean){
                allCost = allCost.add(accountsAllCost);
                overallCost = overallCost.add(accountsOverallCost);
                personalCost = personalCost.add(accountsPersonalCost);
                BigDecimal reissueAmountAdd = reissueAmountTotal.add(reissueAmount);
                BigDecimal deductionAmountAdd = deductionAmountTotal.add(deductionAmount);
                ChDisabAccounts chDisabAccount = new ChDisabAccounts();
                chDisabAccount.setAllCost(allCost);
                chDisabAccount.setOverallCost(overallCost);
                chDisabAccount.setPersonalCost(personalCost);
                chDisabAccount.setAccountsId(accountsId);
                chDisabAccount.setReissueAmountTotal(reissueAmountAdd);
                chDisabAccount.setDeductionAmountTotal(deductionAmountAdd);
                disabAccountsMapper.updateById(chDisabAccount);
            }else {
                // 结算到其他月份 结算表加一个是否暂缓字段 2 暂缓
                ChDisabAccounts chDisabAccounts = disabAccountsMapper.queryAccountByCondition(DateUtils.dateToStrYm(new Date()), chDisabDetailAccountDTO.getModeName(), chDisabDetailAccountDTO.getSrvOrganId(),2);
                if (chDisabAccounts == null) {
                    chDisabAccounts = new ChDisabAccounts();
                    chDisabAccounts.setIsDelay((short)2);
                    chDisabAccounts.setAccountsStatus((short)1);
                    chDisabAccounts.setSrvOrganId(Long.valueOf(chDisabDetailAccountDTO.getSrvOrganId()));
                    chDisabAccounts.setCreationTime(new Date());
                    chDisabAccounts.setAccountsTime(new Date());
                    chDisabAccounts.setModeName(chDisabDetailAccountDTO.getModeName());
                    chDisabAccounts.setDeductionAmountTotal(chDisabDetailAccountDTO.getDeductionAmount());
                    chDisabAccounts.setReissueAmountTotal(chDisabDetailAccountDTO.getReissueAmount());
                    chDisabAccounts.setAllCost(chDisabDetailAccountDTO.getAccountsAllCost());
                    chDisabAccounts.setOverallCost(chDisabDetailAccountDTO.getAccountsOverallCost());
                    chDisabAccounts.setPersonalCost(chDisabDetailAccountDTO.getAccountsPersonalCost());
                    chDisabAccounts.setSvrStartTime(chDisabDetailAccountDTO.getAccountsStartTime());
                    chDisabAccounts.setSvrEndTime(chDisabDetailAccountDTO.getAccountsEndTime());
                    chDisabAccounts.setTotalAllocatedExpenses(BigDecimal.valueOf(0));
                    disabAccountsMapper.insert(chDisabAccounts);
                    accountsId = chDisabAccounts.getAccountsId();
                }else {
                    BigDecimal allCost1 = chDisabAccounts.getAllCost();
                    BigDecimal overallCost1 = chDisabAccounts.getOverallCost();
                    BigDecimal personalCost1 = chDisabAccounts.getPersonalCost();
                    BigDecimal deductionAmountTotal1 = chDisabAccounts.getDeductionAmountTotal();
                    BigDecimal reissueAmountTotal1 = chDisabAccounts.getReissueAmountTotal();
                    BigDecimal deduction = deductionAmountTotal1.add(deductionAmount);
                    BigDecimal reissue = reissueAmountTotal1.add(reissueAmount);
                    allCost1 = allCost1.add(accountsAllCost);
                    overallCost1 = overallCost1.add(accountsOverallCost);
                    personalCost1 = personalCost1.add(accountsPersonalCost);
                    ChDisabAccounts chDisabAccount = new ChDisabAccounts();
                    chDisabAccount.setAllCost(allCost1);
                    chDisabAccount.setOverallCost(overallCost1);
                    chDisabAccount.setPersonalCost(personalCost1);
                    chDisabAccount.setAccountsId(accountsId);
                    chDisabAccount.setReissueAmountTotal(reissue);
                    chDisabAccount.setDeductionAmountTotal(deduction);
                    disabAccountsMapper.updateById(chDisabAccount);
                }
            }
        }
        ChDisabDetailAccounts chDisabDetailAccounts = new ChDisabDetailAccounts();
        chDisabDetailAccounts.setAccountsDetailId(accountsDetailId);
        chDisabDetailAccounts.setStatus(status);
        chDisabDetailAccounts.setAccountsId(accountsId);
        int result = chDisabAccountsDetailMapper.updateById(chDisabDetailAccounts);
        return result;
    }

    @Override
    public int placeOtherApply(Integer disabInfoId, String otherApplyTime) {
        int result =  taskDetailMapper.placeOtherApply(disabInfoId,otherApplyTime);
        BigDecimal limit = BigDecimal.valueOf(20);
        BigDecimal zero = BigDecimal.valueOf(0);
        ChDisabDetailAccounts chDisabDetailAccountsDTO = chDisabAccountsDetailMapper.queryDisabDetailAccounts("471", otherApplyTime, String.valueOf(disabInfoId), "异地");
        if(Objects.isNull(chDisabDetailAccountsDTO)) {
            // 异地
            ChDisabDetailAccounts chDisabDetailAccounts = new ChDisabDetailAccounts();
            chDisabDetailAccounts.setAccountsAllCost(limit);
            chDisabDetailAccounts.setAccountsOverallCost(limit);
            chDisabDetailAccounts.setAccountsPersonalCost(zero);
            chDisabDetailAccounts.setModeName("异地");
            chDisabDetailAccounts.setSrvOrganId("471");
            chDisabDetailAccounts.setCreationTime(new Date());
            chDisabDetailAccounts.setAccountsTime(DateUtils.strToDate(otherApplyTime));
            //  chDisabDetailAccounts.setMedicalArea(accountsVO.getMedicalArea());
            chDisabDetailAccounts.setDisabInfoId(String.valueOf(disabInfoId));
            chDisabDetailAccounts.setStatus((short) 1);
            chDisabDetailAccounts.setReissueAmount(BigDecimal.valueOf(0));
            chDisabDetailAccounts.setDeductionAmount(BigDecimal.valueOf(0));
            ChDisabAccounts chDisabAccounts = disabAccountsMapper.queryAccountByCondition(DateUtils.dateToStrYm(DateUtils.strToDate(otherApplyTime)), "异地", "471", null);
            if (chDisabAccounts == null) {
                chDisabAccounts = new ChDisabAccounts();
                chDisabAccounts.setModeName("异地");
                chDisabAccounts.setAccountsTime(DateUtils.strToDateMd(otherApplyTime));
                chDisabAccounts.setSrvOrganId(Long.valueOf(471));
                chDisabAccounts.setCreationTime(new Date());
                chDisabAccounts.setAccountsStatus((short) 1);
                chDisabAccounts.setAllCost(limit);
                chDisabAccounts.setOverallCost(limit);
                chDisabAccounts.setPersonalCost(zero);
                chDisabAccounts.setReissueAmountTotal(zero);
                chDisabAccounts.setDeductionAmountTotal(zero);
                disabAccountsMapper.insert(chDisabAccounts);
            }
            chDisabDetailAccounts.setAccountsId(chDisabAccounts.getAccountsId());
            chDisabAccountsDetailMapper.insert(chDisabDetailAccounts);
        }else {
            BigDecimal accountsAllCost = chDisabDetailAccountsDTO.getAccountsAllCost();
            BigDecimal accountsOverallCost = chDisabDetailAccountsDTO.getAccountsOverallCost();
            chDisabDetailAccountsDTO.setAccountsAllCost(accountsAllCost.add(limit));
            chDisabDetailAccountsDTO.setAccountsOverallCost(accountsOverallCost.add(limit));
            chDisabDetailAccountsDTO.setAccountsPersonalCost(zero);
            chDisabAccountsDetailMapper.updateById(chDisabDetailAccountsDTO);
        }
        return result;
    }

    @Override
    public Page<PlaceOtherVO> placeOtherQuery(Page page, String name, String certiCode) {
        Page<PlaceOtherVO> placeOtherVOPage = taskDetailMapper.placeOtherQuery(page, name, certiCode);
        return placeOtherVOPage;
    }

}
