package com.hungraim.ltc.controller;

import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.hungraim.ltc.pojo.entity.disable.*;
import com.hungraim.ltc.pojo.vo.disable.*;
import com.hungraim.ltc.service.DisableService;
import com.hungraim.ltc.util.FileUtils;
import com.hungraim.ltc.util.Result;
import com.hungraim.ltc.util.ResultCode;
import com.hungraim.ltc.util.TokenParsingUtil;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.apache.poi.ss.usermodel.Workbook;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 失能申请Controller
 *
 * @author czz
 */
@RestController
@RequestMapping("/api.apply/disable")
@Slf4j
public class DisableController {

    @Autowired
    private DisableService disableService;

    /**
     * 省市区
     *
     * @param districtLevel 区域级别:1省2地级市3县
     * @param districtCode  上级区域代码
     */
    @RequestMapping("/district")
    public Result<List<ChFndDistrict>> district(String districtLevel, String districtCode) {
        List<ChFndDistrict> districts = disableService.district(districtLevel, districtCode);
        return Result.success(districts);
    }

    /**
     * 获取所有省市区街道数据
     *
     * @return 返回树形结构省市区数据
     */
    @RequestMapping("/allDistrict")
    public Result allDistrict() {
        List<DistrictTreeVo> districtTreeVos = disableService.allDistrict();
        return Result.success(districtTreeVos);
    }

    /**
     * 获取所有省市区街道数据，以树形结构返回
     *
     * @return 返回树形结构省市区数据
     */
    @RequestMapping("/allTreeDistrict")
    public Result allTreeDistrict() {
        List<DistrictTreeVo> districtTreeVos = disableService.getAllDistrictTreeData();
        return Result.success(districtTreeVos);
    }

    /**
     * 查询所有父机构
     */
    @RequestMapping("/fndOrganRoot")
    public Result<List<ChFndOrgan>> fndOrganRoot(@RequestHeader("Authorization") String token) {
        long organId = TokenParsingUtil.TokenParsing(token, "organId");
        List<ChFndOrgan> organs = disableService.fndOrganRoot(organId);
        return Result.success(organs);
    }

    /**
     * 查询所有机构
     */
    @RequestMapping("/fndAllOrgan")
    public Result<List<ChFndOrgan>> fndAllOrgan(@RequestHeader("Authorization") String token) {
        long organId = TokenParsingUtil.TokenParsing(token, "organId");
        List<ChFndOrgan> organs = disableService.fndAllOrgan(organId);
        return Result.success(organs);
    }

    /**
     * 查询所有服务方式
     */
    @RequestMapping("/fndSrvMode")
    public Result<List<SrvModeVo>> cfgSrvMode() {
        List<SrvModeVo> fndSrvModes = disableService.cfgSrvModeList();
        return Result.success(fndSrvModes);
    }

    /**
     * 查询机构(不包含子机构)下所有护理机构
     *
     * @param  token
     */
    @RequestMapping("/srvOrganList")
    public Result<List<ChSrvOrgan>> srvOrganList(@RequestHeader("Authorization") String token) {
        long organId = TokenParsingUtil.TokenParsing(token, "organId");
        long srvOrganId = TokenParsingUtil.TokenParsing(token, "srvOrganId");
        List<ChSrvOrgan> chFndSrvModes = disableService.srvOrganList(String.valueOf(organId), srvOrganId, false);
        return Result.success(chFndSrvModes);
    }


    /**
     * 查询意向服务机构
     *
     * @param  organId
     */
    @RequestMapping("/srvOrganList2")
    public Result<List<ChSrvOrgan>> srvOrganList2(String organId) {
        if (StringUtils.isBlank(organId)) {
            return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
        }
        List<ChSrvOrgan> chFndSrvModes = disableService.srvOrganList2(organId, false);
        return Result.success(chFndSrvModes);
    }

    /**
     * 查询机构下或者包含子机构下的所有护理机构
     *
     * @param  token 机构id
     */
    @RequestMapping("/srvOrganListByIsInvolveChild")
    public Result<List<ChSrvOrgan>> srvOrganListByIsInvolveChild(@RequestHeader("Authorization") String token, Boolean isInvolveChild) {
        long organId = TokenParsingUtil.TokenParsing(token, "organId");
        long srvOrganId = TokenParsingUtil.TokenParsing(token, "srvOrganId");
        if (null == isInvolveChild) {
            isInvolveChild = false;
        }
        List<ChSrvOrgan> chFndSrvModes = disableService.srvOrganList(String.valueOf(organId),srvOrganId, isInvolveChild);
        return Result.success(chFndSrvModes);
    }

    /**
     * 查询疾病类型
     *
     * @param parDiseTypeId 父疾病类型id 不传值默认查询所有一级疾病类型
     */
    @RequestMapping("/fndDiseaseList")
    public Result<List<ChFndDiseaseType>> fndDiseaseList(String parDiseTypeId) {
        List<ChFndDiseaseType> chFndDiseaseTypes = disableService.fndDiseaseList(parDiseTypeId);
        return Result.success(chFndDiseaseTypes);
    }

    /**
     * 查询所有疾病数据
     */
    @RequestMapping("/fndAllDisease")
    public Result<List<ChFndDiseaseType>> fndAllDisease() {
        List<ChFndDiseaseType> chFndDiseaseTypes = disableService.fndAllDisease();
        return Result.success(chFndDiseaseTypes);
    }

    /**
     * 查询护理机构下所有子机构id
     *
     * @param organId 机构id
     * @return 机构及所有子机构id, 以逗号分隔, 如果没有子机构则只返回机构id
     */
    @RequestMapping("/subsidiariesOrganId")
    public Result<String> subsidiariesOrganId(String organId) {
        if (StrUtil.isBlank(organId)) {
            return Result.failed("organId不能为空!");
        }
        return Result.success(disableService.subsidiariesOrganId(organId));
    }

    /**
     * 失能人员信息列表
     *
     * @param organId            适用机构代码
     * @param districtProvincial 所在省
     * @param districtCity       所在市
     * @param districtArea       所在区域
     * @param realName           失能人员姓名
     * @param certiCode          失能人员身份证号码
     * @param dataFrom           申请来源
     * @param srvOrganName       护理机构名称
     * @param pageNum            当前页
     * @param pageSize           每页几条数据
     * @return 失能人员信息列表
     */
    @RequestMapping("/disableList")
    public Result<Page<DisableVO>> disableList(@RequestParam(defaultValue = "1") Integer pageNum, @RequestParam(defaultValue = "10") Integer pageSize,
                                               String organId, String districtProvincial,
                                               String districtCity, String districtArea,
                                               String realName, String certiCode, String dataFrom,
                                               String srvOrganName) {
        Page<DisableVO> page = new Page<>(pageNum, pageSize);
        page = disableService.disableList(page, organId, districtProvincial,
                districtCity, districtArea, realName, certiCode, dataFrom, srvOrganName, 1);
        return Result.success(page);
    }

    /**
     * 失能人员信息列表
     *
     * @param organId            适用机构代码
     * @param districtProvincial 所在省
     * @param districtCity       所在市
     * @param districtArea       所在区域
     * @param realName           失能人员姓名
     * @param certiCode          失能人员身份证号码
     * @param dataFrom           申请来源
     * @param srvOrganName       护理机构名称
     * @param pageNum            当前页
     * @param pageSize           每页几条数据
     * @return 失能人员信息列表
     */
    @RequestMapping("/reApplyList")
    public Result<Page<DisableVO>> reApplyList(@RequestParam(defaultValue = "1") Integer pageNum, @RequestParam(defaultValue = "10") Integer pageSize,
                                               String organId, String districtProvincial,
                                               String districtCity, String districtArea,
                                               String realName, String certiCode, String dataFrom,
                                               String srvOrganName) {
        Page<DisableVO> page = new Page<>(pageNum, pageSize);
        page = disableService.disableList(page, organId, districtProvincial,
                districtCity, districtArea, realName, certiCode, dataFrom, srvOrganName, 2);
        return Result.success(page);
    }


    /**
     *@author zwl
     *@desc 失能人员导出
     *@date 2023/1/7
     *@param  * @param organId
     * @param districtProvincial
     * @param districtCity
     * @param districtArea
     * @param realName
     * @param certiCode
     * @param dataFrom
     * @param response
     *@return void
     **/
    @RequestMapping("/download")
    public void download(String organId, String districtProvincial,
                         String districtCity, String districtArea,
                         String realName, String certiCode, String dataFrom,HttpServletResponse response){
        Workbook workbook = disableService.disableDownload(organId, districtProvincial,
                districtCity, districtArea, realName, certiCode, dataFrom,1);
        // 命名表格
        String fileName = "disable.xlsx";
        FileUtils.exportResponse(workbook,fileName,response);
    }


    /**
     * 失能审核信息详情
     *
     * @param applyId 失能人员id
     * @return 失能信息详情
     */
    @RequestMapping("/disableExamineInfo")
    public Result<DisableExamineInfoVO> disableExamineInfo(String applyId) {
        DisableExamineInfoVO disableExamineInfoVO = disableService.disableExamineInfo(applyId);
        return Result.success(disableExamineInfoVO);
    }

    /**
     * 失能审核
     *
     * @param applyId     申请id
     * @param checkName   审核人
     * @param applyStatus 审核结果
     * @param checkRemark 审核备注
     * @return 失能审核信息详情
     */
    @RequestMapping("/disableExamine")
    public Result disableExamine(String applyId, String checkName, Short applyStatus, String checkRemark) {
        disableService.disableExamine(applyId, checkName, applyStatus, checkRemark);
        return Result.success();
    }

    /**
     * 修改失能申请
     */
    @RequestMapping("/updateDisable")
    public Result updateDisable(ChDisableApply chDisableApply) {
        if (chDisableApply.getApplyId() == null) {
            return Result.failed("请求参数错误");
        }

        if (StringUtils.isBlank(chDisableApply.getDistrictProvincial()) || StringUtils.isBlank(chDisableApply.getDistrictCity()) || StringUtils.isBlank(chDisableApply.getDistrictArea())) {
            return Result.failed("所在省市不能为空!");
        }
        if (StringUtils.isBlank(chDisableApply.getRealName())) {
            return Result.failed("申请人姓名不能为空!");
        }
        if (StringUtils.isBlank(chDisableApply.getCertiCode())) {
            return Result.failed("身份证号码不能为空!");
        }
        if (chDisableApply.getBirthday() == null) {
            return Result.failed("出生年月日不能为空!");
        }
        if (StringUtils.isBlank(chDisableApply.getGender())) {
            return Result.failed("性别不能为空!");
        }
        if (StringUtils.isBlank(chDisableApply.getTel())) {
            return Result.failed("手机号不能为空!");
        }
//        if (chDisableApply.getRegist() == null) {
//            return Result.failed("所在户籍不能为空!");
//        }
        //StringUtils.isBlank(chDisableApply.getAcptStreet()) ||
        if (StringUtils.isBlank(chDisableApply.getAcptProvincial()) || StringUtils.isBlank(chDisableApply.getAcptCity()) || StringUtils.isBlank(chDisableApply.getAcptArea()) ||  StringUtils.isBlank(chDisableApply.getAcptAddress())) {
            return Result.failed("接受评定地址不能为空!");
        }
        if (StringUtils.isBlank(chDisableApply.getAcptSrvProvincial()) || StringUtils.isBlank(chDisableApply.getAcptSrvCity()) || StringUtils.isBlank(chDisableApply.getAcptSrvArea()) || StringUtils.isBlank(chDisableApply.getAcptSrvAddress())) {
            return Result.failed("接受服务地址不能为空!");
        }
        if (StringUtils.isBlank(chDisableApply.getAdressDistrictProvincial()) || StringUtils.isBlank(chDisableApply.getAdressDistrictCity()) || StringUtils.isBlank(chDisableApply.getAdressDistrictCode())   || StringUtils.isBlank(chDisableApply.getAdressDetail())) {
            return Result.failed("现住址不能为空!");
        }

        if (chDisableApply.getSrvModeId() == null) {
            return Result.failed("申请服务方式不能为空!");
        }
        if (chDisableApply.getDiseTypeF() == null) {
            return Result.failed("诊断疾病不能为空!");
        }
      /*  if (StringUtils.isBlank(chDisableApply.getDiseaseDesc())) {
            return Result.failed("疾病描述及诊断不能为空!");
        }*/
        if (chDisableApply.getMedicalType() == null) {
            return Result.failed("医保类型不能为空!");
        }
        disableService.updateDisable(chDisableApply);
        return Result.success();
    }

    /**
     * 新增失能申请
     */
    @RequestMapping("/addDisable")
    public Result addDisable(@RequestHeader("Authorization") String token,ChDisableApply chDisableApply) {
        long srvOrganId = TokenParsingUtil.TokenParsing(token, "srvOrganId");
        //字段校验
        //所在省市区
        if (StringUtils.isBlank(chDisableApply.getDistrictProvincial()) || StringUtils.isBlank(chDisableApply.getDistrictCity()) || StringUtils.isBlank(chDisableApply.getDistrictArea())) {
            return Result.failed("所在省市不能为空!");
        }
        if (StringUtils.isBlank(chDisableApply.getRealName())) {
            return Result.failed("申请人姓名不能为空!");
        }
        if (StringUtils.isBlank(chDisableApply.getCertiCode())) {
            return Result.failed("身份证号码不能为空!");
        }
        if (chDisableApply.getBirthday() == null) {
            return Result.failed("出生年月日不能为空!");
        }
        if (StringUtils.isBlank(chDisableApply.getGender())) {
            return Result.failed("性别不能为空!");
        }
        if (StringUtils.isBlank(chDisableApply.getTel())) {
            return Result.failed("手机号不能为空!");
        }
        /*if (chDisableApply.getRegist() == null) {
            return Result.failed("所在户籍不能为空!");
        }*/

        //StringUtils.isBlank(chDisableApply.getAcptStreet()) ||
        if (StringUtils.isBlank(chDisableApply.getAcptProvincial()) || StringUtils.isBlank(chDisableApply.getAcptCity()) || StringUtils.isBlank(chDisableApply.getAcptArea()) ||  StringUtils.isBlank(chDisableApply.getAcptAddress())) {
            return Result.failed("接受评定地址不能为空!");
        }
        //|| StringUtils.isBlank(chDisableApply.getAcptSrvStreet())
        if (StringUtils.isBlank(chDisableApply.getAcptSrvProvincial()) || StringUtils.isBlank(chDisableApply.getAcptSrvCity()) || StringUtils.isBlank(chDisableApply.getAcptSrvArea())  || StringUtils.isBlank(chDisableApply.getAcptSrvAddress())) {
            return Result.failed("接受服务地址不能为空!");
        }
        //|| StringUtils.isBlank(chDisableApply.getStreet())
        if (StringUtils.isBlank(chDisableApply.getAdressDistrictProvincial()) || StringUtils.isBlank(chDisableApply.getAdressDistrictCity()) || StringUtils.isBlank(chDisableApply.getAdressDistrictCode())  || StringUtils.isBlank(chDisableApply.getAdressDetail())) {
            return Result.failed("现住址不能为空!");
        }

        if (chDisableApply.getSrvModeId() == null) {
            return Result.failed("申请服务方式不能为空!");
        }
        if (chDisableApply.getDiseTypeF() == null) {
            return Result.failed("诊断疾病不能为空!");
        }

   /*     if (StringUtils.isBlank(chDisableApply.getDiseaseDesc())) {
            return Result.failed("疾病描述及诊断不能为空!");
        }*/
        if (chDisableApply.getMedicalType() == null) {
            return Result.failed("医保类型不能为空!");
        }
        return disableService.addDisable(chDisableApply);
    }

    /**
     * 查询失能人员信息
     *
     * @param disableInfoId 失能人员id
     */
    @RequestMapping("/getDisableInfo")
    public Result getDisableInfo(String disableInfoId) {
        if (StringUtils.isBlank(disableInfoId)) {
            return Result.failed("请求参数错误");
        }
        DisableInfoVO disableInfoVO = disableService.getDisableInfo(disableInfoId);
        return Result.success(disableInfoVO);
    }

    /**
     * 失能人员信息变更-新增修改
     * 先把info的数据带出来，更改完，存到这个变更表
     */
    @PostMapping("/addOrUpdateDisInfoChange")
    public Result addOrUpdateDisInfoChange(DisableUpdateDetailVO disableUpdateDetailVO) {
        //StrUtil.isBlank(disableUpdateDetailVO.getAcptStreet()) || StrUtil.isBlank(disableUpdateDetailVO.getAddressStreet()) || null == disableUpdateDetailVO.getRegist() ||
        if (null == disableUpdateDetailVO.getDisabInfoId() || StrUtil.isBlank(disableUpdateDetailVO.getOrganId()) || StrUtil.isBlank(disableUpdateDetailVO.getDistrictProvince()) || StrUtil.isBlank(disableUpdateDetailVO.getDistrictCity()) || StrUtil.isBlank(disableUpdateDetailVO.getDistrictArea()) || StrUtil.isBlank(disableUpdateDetailVO.getRealName()) || StrUtil.isBlank(disableUpdateDetailVO.getCertifNum()) || null == disableUpdateDetailVO.getBirthday() || StrUtil.isBlank(disableUpdateDetailVO.getGender()) || StrUtil.isBlank(disableUpdateDetailVO.getTel()) ||  StrUtil.isBlank(disableUpdateDetailVO.getAcptProvincial()) || StrUtil.isBlank(disableUpdateDetailVO.getAcptCity()) || StrUtil.isBlank(disableUpdateDetailVO.getAcptArea()) ||  StrUtil.isBlank(disableUpdateDetailVO.getAcptDetail()) || StrUtil.isBlank(disableUpdateDetailVO.getAcptSrvProvincial()) || StrUtil.isBlank(disableUpdateDetailVO.getAcptSrvCity()) || StrUtil.isBlank(disableUpdateDetailVO.getAcptSrvArea())  || StrUtil.isBlank(disableUpdateDetailVO.getAcptSrvAddress()) || null == disableUpdateDetailVO.getAcptSrvType() || StrUtil.isBlank(disableUpdateDetailVO.getAddressProvincial()) || StrUtil.isBlank(disableUpdateDetailVO.getAddressCity()) || StrUtil.isBlank(disableUpdateDetailVO.getAddressArea()) ||  StrUtil.isBlank(disableUpdateDetailVO.getAddressDetail()) || null == disableUpdateDetailVO.getAddressType() || StrUtil.isBlank(disableUpdateDetailVO.getChangeReason())) {
            return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
        }
        return disableService.addOrUpdateDisInfoChange(disableUpdateDetailVO);
    }


    /**
     * 失能人员信息变更-审核列表
     */
    @GetMapping("/listDisInfoChangeExamine")
    public Result<Page<DisableInfoChangeVo>> getListDisInfoChangeExamine(@RequestParam(defaultValue = "1") Integer pageNum, @RequestParam(defaultValue = "10") Integer pageSize,
                                                                         Long organId, Boolean isChildGroup, String districtProvincial, String districtCity, String districtArea,
                                                                         String realName, String certiCode, String srvOrganName, Short applyStatus) {
        Page<DisableInfoChangeVo> page = new Page<>(pageNum, pageSize);
        page = disableService.ListDisInfoChangeExamine(page, organId, isChildGroup, districtProvincial
                , districtCity, districtArea, realName, certiCode, srvOrganName, applyStatus);
        return Result.success(page);

    }

    /**
     * 失能人员信息变更-审核
     * 审核通过再更新到info表
     */
    @PostMapping("/doDisInfoChangeExamine")
    public Result doDisInfoChangeExamine(String changeId, String checkName, Short applyStatus, String checkRemark) {
        disableService.DisableInfoChangeExamine(changeId, checkName, applyStatus, checkRemark);
        return Result.success();
    }

    /**
     * 失能人员信息修改申请详情页搜索失能人员接口
     *
     * @param pageNum  翻页参数
     * @param pageSize 翻页参数
     * @param realName 失能人员姓名
     * @return 返回一组人员信息
     */
    @GetMapping("/searchByRealName")
    public Result<IPage<SearchDisableSimpleVo>> searchByRealName(@RequestParam(defaultValue = "1") Integer pageNum, @RequestParam(defaultValue = "10") Integer pageSize, String realName) {
        if (StringUtils.isBlank(realName)) {
            return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
        }
        IPage<SearchDisableSimpleVo> searchDisableSimpleVoIPage = disableService.searchByRealName(pageNum, pageSize, realName);
        return Result.success(searchDisableSimpleVoIPage);
    }


    /**
     * 失能人员信息详情（失能人员信息修改申请详情页面-新增）
     *
     * @param disabInfoId 失能人员id
     * @return 失能信息详情
     */
    @RequestMapping("/disableInfoUpdateDetail")
    public Result<DisableUpdateDetailVO> disableInfoUpdateDetail(String disabInfoId) {
        if (StrUtil.isBlank(disabInfoId)) {
            return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
        }
        DisableUpdateDetailVO disableUpdateDetailVO = disableService.disableInfoUpdateDetail(disabInfoId);
        return Result.success(disableUpdateDetailVO);
    }

    /**
     * 失能人员变更信息详情(失能人员信息修改申请详情页面-查看、修改)
     *
     * @param changeId 变更id
     * @return 失能人员变更信息详情
     */
    @RequestMapping("/changeDisableDetail")
    public Result<DisableUpdateDetailVO> changeDisableDetail(Integer changeId) {
        if (null == changeId) {
            return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
        }
        DisableUpdateDetailVO disableUpdateDetailVO = disableService.changeDisableDetail(changeId);
        return Result.success(disableUpdateDetailVO);
    }

    /**
     * 失能人员信息退出列表
     *
     * @param pageNum            当前页
     * @param pageSize           每页几条数据
     * @return 失能人员信息列表
     */
    @RequestMapping("/disableInfoList")
    public Result<Page<DisableInfoListVo>> disableInfoList(@RequestHeader("Authorization") String token,Integer pageNum, Integer pageSize, Long srvOrganId,String certiCode,String realName,String svrModelId) {
        if (pageNum == null || pageNum < 1) {
            return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
        }
        if (pageSize == null || pageSize < 1) {
            pageSize = 10;
        }
        long srvOrganIdL = TokenParsingUtil.TokenParsing(token, "srvOrganId");
        if(srvOrganIdL != 0) {
            srvOrganId = new Long(srvOrganIdL);
        }
        Page<DisableInfoListVo> page = new Page<>(pageNum, pageSize);
        page = disableService.getDisableInfoList(page, srvOrganId,certiCode,realName,svrModelId);
        return Result.success(page);
    }


    /**
     * 失能人员退出
     */
    @RequestMapping("/disableInfoExit")
    public Result disableInfoExit(Integer disableInfoId,Integer exitReasonId,Integer applyId, Integer srvOrganId,Integer programId,String exitTime) {
        if (disableInfoId == null|| exitReasonId == null||applyId == null) {
            return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
        }
        int i = disableService.disableInfoExit(disableInfoId,exitReasonId,applyId,srvOrganId,programId,exitTime);
        if (i > 0) {
            return Result.success();
        } else {
            return Result.failed();
        }


    }


    /**
     * 失能人员信息退出历史列表
     *
     * @param disableInfoId
     * @return 失能人员信息退出历史列表
     */
    @RequestMapping("/getDisableExitHis")
    public Result<List<ChDisableExit>> getDisableExitHis(Integer disableInfoId) {
        if (disableInfoId == null) {
            return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
        }
        List<ChDisableExit> disableExitHis = disableService.getDisableExitHis(disableInfoId);
        return Result.success(disableExitHis);
    }

    @RequestMapping("/getDisableCertiCode")
    public Result getDisableCertiCode(String certiCode) {
        if (certiCode == null) {
            return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
        }
        Integer integer = disableService.selectByCertiCode(certiCode);
        if (integer > 0) {
           // return Result.failed("失能申请已存在该人员身份证，请联系管理员");
            return Result.success(2);
        }
        return Result.success(1);
    }

}
