package com.hungraim.ltc.service;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.hungraim.ltc.pojo.entity.SysConfig.ChCfgSrvOrganType;
import com.hungraim.ltc.pojo.entity.SysConfig.ChFndSrvOrganLevel;
import com.hungraim.ltc.pojo.vo.disable.SrvOrganListVo;
import com.hungraim.ltc.pojo.vo.system.SrvOrganVo;

import java.util.List;

public interface SrvOrganService {

    /**
     * 分页查询护理机构列表
     *
     * @param page           分页对象
     * @param organId        适用机构id
     * @param isInvolveChild 是否包含下层机构
     * @param creditCode     统一社会信用代码
     * @param srvOrganName   护理机构名称
     * @return 返回护理机构列表
     */
    Page<SrvOrganListVo> getSrvOrganList(Page<SrvOrganListVo> page, Long organId, Boolean isInvolveChild, String creditCode, String srvOrganName,Long srvOrganId);

    /**
     * 获取所有服务机构等级
     *
     * @return 返回服务机构等级
     */
    List<ChFndSrvOrganLevel> getSrvOrganLevels();

    /**
     * 获取所有服务机构类型
     *
     * @return 返回所有服务机构类型
     */
    List<ChCfgSrvOrganType> getSrvOrganTypes();

    /**
     * 添加护理机构
     *
     * @param srvOrganVo 护理机构包装对象
     */
    void saveOrUpdateSrvOrgan(SrvOrganVo srvOrganVo);

    /**
     * 查询护理机构详情
     *
     * @param srvOrganId 护理机构id
     * @return 返回护理机构详情
     */
    SrvOrganVo getSrvOrganDetail(Long srvOrganId);

    /**
     * 删除护理机构
     *
     * @param srvOrganId 护理机构id
     */
    void deleteSrvOrgan(Long srvOrganId);

}
