package com.hungraim.ltc.controller;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.hungraim.ltc.pojo.vo.assessment.ChAprTaskVo;
import com.hungraim.ltc.pojo.vo.assessment.ReTaskDistributionVO;
import com.hungraim.ltc.pojo.vo.disable.ChDisableApplyVo;
import com.hungraim.ltc.service.ReTaskService;
import com.hungraim.ltc.util.Result;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * 复评Controller
 *
 * @author czz
 */
@RestController
@RequestMapping("/api.assessment/reTask")
@Slf4j
public class ReTaskController {

    @Autowired
    private ReTaskService reTaskService;

    /**
     * 可以进行复评申请的列表
     *
     * @param organId            适用机构id
     * @param isChildGroup       是否包含下级机构,值为true，则包含organId的下层机构
     * @param districtProvincial 所在省
     * @param districtCity       所在市
     * @param districtArea       所在区域
     * @param realName           失能人员姓名
     * @param certiCode          失能人员身份证号码
     * @param pageNum            当前页
     * @param pageSize           每页几条数据
     */
    @RequestMapping("/reTaskDistributionList")
    public Result<Page<ReTaskDistributionVO>> reTaskDistributionList(@RequestParam(defaultValue = "1") Integer pageNum, @RequestParam(defaultValue = "10") Integer pageSize,
                                                                     Long organId, Boolean isChildGroup, String districtProvincial, String districtCity, String districtArea,
                                                                     String realName, String certiCode) {
        Page<ReTaskDistributionVO> page = new Page<>(pageNum, pageSize);
        page = reTaskService.reTaskDistributionList(page, organId, isChildGroup, districtProvincial, districtCity, districtArea, realName, certiCode);
        return Result.success(page);
    }

    /**
     * 复评申请详情(作废)
     */
    @GetMapping("/reassmentDetail")
    public Result reassmentDetailById(String applyId) {
        ChDisableApplyVo chDisableApplyVo = reTaskService.reassmentDetailById(applyId);
        if (chDisableApplyVo != null) {
            return Result.success(chDisableApplyVo);
        }
        return Result.failed("没有查到该复评申请数据");
    }

    /**
     * 复评申请-历史评定信息
     */
    @GetMapping("/hisinfo-list")
    public Result<List<ChAprTaskVo>> getRetaskHisList(String disableInfoId) {
        if (StringUtils.isBlank(disableInfoId)) {
            return Result.failed("查询参数错误");
        }
        List<ChAprTaskVo> chAprTaskVos = reTaskService.geReTaskHisInfoList(disableInfoId);
        return Result.success(chAprTaskVos);
    }

    /**
     * 复评审核
     */
    @RequestMapping("/disableExamine")
    public Result disableExamine(String applyId, String checkName, Short applyStatus, String checkRemark) {
        if (StringUtils.isBlank(applyId) || StringUtils.isBlank(checkName) || null == applyStatus) {
            return Result.failed("查询参数错误");
        }
        reTaskService.disableExamine(applyId, checkName, applyStatus, checkRemark);
        return Result.success();
    }

}
