package com.hungraim.ltc.service.impl;

import cn.afterturn.easypoi.excel.ExcelExportUtil;
import cn.afterturn.easypoi.excel.entity.ExportParams;
import cn.afterturn.easypoi.excel.entity.enmus.ExcelType;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.hungraim.ltc.api.AttachFeignService;
import com.hungraim.ltc.dao.*;
import com.hungraim.ltc.pojo.entity.SysConfig.ChFndAttach;
import com.hungraim.ltc.pojo.entity.assessment.*;
import com.hungraim.ltc.pojo.entity.disable.ChCfgSrvDisableLevel;
import com.hungraim.ltc.pojo.entity.disable.ChDisableInfo;
import com.hungraim.ltc.pojo.vo.ReportUpdateVO;
import com.hungraim.ltc.pojo.vo.account.AssessAccountsExportResp;
import com.hungraim.ltc.pojo.vo.account.AssessAccountsListResp;
import com.hungraim.ltc.pojo.vo.assessment.*;
import com.hungraim.ltc.pojo.vo.system.AttachUpdateVo;
import com.hungraim.ltc.service.ChAprReportFractionService;
import com.hungraim.ltc.service.TaskService;
import com.hungraim.ltc.service.TppesApiException;
import com.hungraim.ltc.util.*;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.apache.poi.ss.usermodel.Workbook;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.math.BigDecimal;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.*;
import java.util.stream.Collectors;

/**
 * @author czz
 */
@Service
@Slf4j
@AllArgsConstructor
public class TaskServiceImpl implements TaskService {

    private final TaskMapper taskMapper;
    private final AprEmpMapper aprEmpMapper;
    private final AprReportMapper aprReportMapper;
    private final AprPersonInfoMapper personInfoMapper;
    private final TaskPushMapper taskPushMapper;
    private final TaskPushHisMapper taskPushHisMapper;
    private final CfgSrvDisableLevelMapper cfgSrvDisableLevelMapper;
    private final DisableInfoMapper disableInfoMapper;
    private final RefuseReasonMapper refuseReasonMapper;
    private final AttachFeignService attachFeignService;

    private final ChAprReportFractionService chAprReportFractionService;

    private final ChAprReportFractionMapper chAprReportFractionMapper;

    private final ChTaskReportFractionDtlMapper chTaskReportFractionDtlMapper;


    private final ChAssessAccountsMapper chAssessAccountsMapper;

    private final ChAssessAccountsDetailMapper chAssessDetailAccountsMapper;




    /**
     * 评定任务分配列表
     *
     * @param organId       适用机构代码
     * @param provincial    所在省
     * @param city          所在市
     * @param area          所在区域
     * @param street        所在街道
     * @param realName      失能人员姓名
     * @param certiCode     失能人员身份证号码
     * @param taskName      评定人员姓名
     * @param taskTel       评定人员手机号码
     * @param daysRemaining 评定剩余天数
     * @param taskStatus        任务状态
     * @param isReturn      是否退回
     * @param type         0-评定任务分配检索 1-评定报告录入查询失能人员  2-评定任务查询检索
     */
    @Override
    public Page<TaskDistributionVO> taskDistributionList(Page<TaskDistributionVO> page, String organId, String provincial, String city,
                                                         String street, String realName, String certiCode, String taskName, String taskTel,
                                                         String daysRemaining, String taskStatus, String isReturn, String area,int type) {
        List<String> organIds = null;
        if (StrUtil.isNotBlank(organId)) {
            organIds = Arrays.asList(organId.split(","));
        }
        int aprType=0;
        if(type!=2){
            if (StrUtil.isNotBlank(realName)||StrUtil.isNotBlank(certiCode)) {
                int count = taskMapper.queryApplyCount(realName,certiCode,2,2);
                aprType=count>0?1:0;//count>0 复评已过，查询复评数据，反之查询初评数据。
            }
        }
        return taskMapper.taskDistributionList(page, organIds, provincial, city,
                street, realName, certiCode, taskName, taskTel, daysRemaining, taskStatus, isReturn, area,type,aprType);
    }

    /**
     * 评定报告录入列表
     *
     * @param name      失能人员姓名
     * @param certiCode 失能人员身份证号码
     * @param tel       失能人员手机号码
     */
    @Override
    public Page<TaskReportVO> taskReportList(Page<TaskReportVO> page,String name, String certiCode, String tel,String riskLevel,Integer evaluateType) {
        return taskMapper.taskReportList(page,name, certiCode, tel,riskLevel,evaluateType);
    }

    /**
     * 查询评定人员列表
     *
     * @param organName   评定机构名称
     * @param name        评定人员姓名
     * @param tel         评定人员手机号码
     * @param groupLeader 是否组长0组长，1非组长
     */
    @Override
    public List<AprEmpVO> aprEmpList(String provincial, String city, String area, String organName, String name, String tel, String groupLeader) {
        List<AprEmpVO> aprEmpVOS = taskMapper.aprEmpList(provincial, city, area, organName, name, tel, groupLeader);
        /*
        如果省市区下没有对应的组长,就查询省市下的对应组长,如果省市下也没有就查询省下的组长
         */
        if (aprEmpVOS == null || aprEmpVOS.size() <= 0) {
            /*if (StringUtils.isNotBlank(provincial) || StringUtils.isNotBlank(city) || StringUtils.isNotBlank(area)) {
                aprEmpVOS = taskMapper.aprEmpList(provincial, city, null, organName, name, tel, groupLeader);
                if (aprEmpVOS == null || aprEmpVOS.size() <= 0) {
                    aprEmpVOS = taskMapper.aprEmpList(provincial, null, null, organName, name, tel, groupLeader);
                }
            }*/
            aprEmpVOS = taskMapper.aprEmpList(null, null, null, organName, name, tel, groupLeader);
        }
        return aprEmpVOS;
    }

    /**
     * 评定报告新增
     * ReportDetailVO reportDetailVO
     */
    @Transactional(rollbackFor = Exception.class)
    @Override
    public Result<Object> addReport(ReportDetailVO reportDetailVO) {
        //Integer taskId, Integer person1, Integer person2, Integer person3, Date evaluateTime, Integer disableLevelId, String polNo, String remark, List<ChFndAttach> fileDataList,List<ChAprReportFraction> chAprReportFractions
        List<ChAprReport> chAprReports = aprReportMapper.selectList(new LambdaQueryWrapper<ChAprReport>().eq(ChAprReport::getStatus, 4).eq(ChAprReport::getTaskId, reportDetailVO.getTaskId()));
        if (chAprReports != null && chAprReports.size() > 0) {
            return Result.failed("已存在的评定任务报告!");
        }
        //插入评定任报告
        ChAprReport report = new ChAprReport();
        report.setTaskId(reportDetailVO.getTaskId());
        report.setEffTime(new Date());
        report.setRemark(reportDetailVO.getRemark());
        report.setDisableLevelId(reportDetailVO.getDisableLevelId());
        report.setPolNo(reportDetailVO.getPolNo());
        report.setStatus(0);
        Date evaluateDate;
        try {
            SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
            evaluateDate = sdf.parse(reportDetailVO.getEvaluateTime());
        } catch (ParseException e) {
            return Result.failed("评估时间格式不正确!");
        }

        report.setEvaluateTime(evaluateDate);
        report.setEvaluateType(reportDetailVO.getEvaluateType());
        aprReportMapper.insert(report);
        //附件上传
        if (reportDetailVO.getFileDataList() != null && reportDetailVO.getFileDataList().size() > 0) {
            updateAttachs(reportDetailVO.getFileDataList(), report.getReportId().longValue());
        }
        //插入评定任务关联人员1.2(两位)
        //person1
        ChAprPersonInfo person1Info = new ChAprPersonInfo();
        person1Info.setReportId(report.getReportId());
        person1Info.setEmpId(reportDetailVO.getPerson1());
        person1Info.setFcd(new Date());
        personInfoMapper.insert(person1Info);
        if (reportDetailVO.getPerson2() != null) {
            ChAprPersonInfo personInfo = new ChAprPersonInfo();
            personInfo.setReportId(report.getReportId());
            personInfo.setEmpId(reportDetailVO.getPerson2());
            personInfo.setFcd(new Date());
            personInfoMapper.insert(personInfo);
        }
        /*if (person3 != null) {
            ChAprPersonInfo personInfo = new ChAprPersonInfo();
            personInfo.setReportId(report.getReportId());
            personInfo.setEmpId(person1);
            personInfo.setFcd(new Date());
            personInfoMapper.insert(personInfo);
        }*/
        if(!reportDetailVO.getChAprReportFractions().isEmpty() && reportDetailVO.getChAprReportFractions().size()>0){
            for (ChAprReportFraction chAprReportFraction: reportDetailVO.getChAprReportFractions()) {
                chAprReportFraction.setReportId(report.getReportId());
            }
            chAprReportFractionService.insertChAprReportFraction(reportDetailVO.getChAprReportFractions());
        }
        // 更新评定任务状态为已完成，并记录完成时间
        ChAprTask task = new ChAprTask();
        task.setTaskId(reportDetailVO.getTaskId());
        task.setFinishTime(new Date());
        task.setTaskStatus(3); // 已完成
        taskMapper.updateById(task);
        if(2 == reportDetailVO.getEvaluateType()){
            ChAprTask chAprTask = taskMapper.selectById(reportDetailVO.getTaskId());
            Integer disableInfoId = chAprTask.getDisableInfoId();
            taskMapper.insertSrvSend(disableInfoId);
        }
        return Result.success();
    }

    @Override
    public void assessAccount(ReportDetailVO reportDetailVo){
        Integer disableLevelId = reportDetailVo.getDisableLevelId();
        if(disableLevelId==1||disableLevelId ==2 ){
            return;
        }
        Integer person1 = reportDetailVo.getPerson1();
        Integer person2 = reportDetailVo.getPerson2();
        String evaluateTime = reportDetailVo.getEvaluateTime();
        Date evaluateDate = DateUtils.strToDate(evaluateTime);
        String certiCode = reportDetailVo.getCertiCode();
        ChDisableInfo chDisableInfo = taskMapper.selectDisableBycertiCode(certiCode);
        Integer srvModeId = chDisableInfo.getSrvModeId();
        // 根据评定机构id和评估结算时间查找表里有没有数据，有数据直接累加费用
        // 评定人员结算表插入
        if (person1 != null) {
            ChAssessDetailAccounts  chAssessDetailAccounts = chAssessDetailAccountsMapper.selectAssessDetailInfo(chDisableInfo.getApplyId(), person1, reportDetailVo.getEvaluateType());
            if(Objects.isNull(chAssessDetailAccounts)){
                chAssessDetailAccounts = new ChAssessDetailAccounts();
                chAssessDetailAccounts.setEmpId(String.valueOf(person1));
                ChAprEmp chAprEmp = aprEmpMapper.selectById(person1);

                Integer aprOrganId = chAprEmp.getAprOrganId();
                chAssessDetailAccounts.setAprOrganId(String.valueOf(aprOrganId));
                chAssessDetailAccounts.setApplyId(String.valueOf(chDisableInfo.getApplyId()));
                chAssessDetailAccounts.setCreationTime(new Date());
                chAssessDetailAccounts.setAccountsTime(evaluateDate);
                chAssessDetailAccounts.setAssessTime(evaluateDate);
                chAssessDetailAccounts.setEvaluateType(reportDetailVo.getEvaluateType());
                Integer aprempTypeIdS = chAprEmp.getAprempTypeIdS();
                // 1 评估员上门评估，每人次 100 元
                // 5 评估专家上门评估，每人次 150 元
                String assessCost = aprempTypeIdS==1? "100":"150";
                chAssessDetailAccounts.setAssessCost(assessCost);
                Long assessAccountsId = saveAssess(aprOrganId, assessCost,srvModeId,evaluateDate);
                if(assessAccountsId != null){
                    chAssessDetailAccounts.setAssessAccountsId(assessAccountsId);
                    chAssessDetailAccountsMapper.insert(chAssessDetailAccounts);
                }
            }else {
                log.info("{}，该失能人员已进行评估结算，护理人员:{}",chDisableInfo.getApplyId(),person1);
            }


        }
        if (person2 != null) {
            ChAssessDetailAccounts chAssessDetailAccounts = chAssessDetailAccountsMapper.selectAssessDetailInfo(chDisableInfo.getApplyId(), person2, reportDetailVo.getEvaluateType());
            if (Objects.isNull(chAssessDetailAccounts)) {
                chAssessDetailAccounts = new ChAssessDetailAccounts();
                chAssessDetailAccounts.setEmpId(String.valueOf(person2));
                ChAprEmp chAprEmp = aprEmpMapper.selectById(person2);
                Integer aprOrganId = chAprEmp.getAprOrganId();
                chAssessDetailAccounts.setAprOrganId(String.valueOf(aprOrganId));
                chAssessDetailAccounts.setApplyId(String.valueOf(chDisableInfo.getApplyId()));
                chAssessDetailAccounts.setCreationTime(new Date());
                chAssessDetailAccounts.setAccountsTime(evaluateDate);
                chAssessDetailAccounts.setAssessTime(evaluateDate);
                chAssessDetailAccounts.setEvaluateType(reportDetailVo.getEvaluateType());
                Integer aprempTypeIdS = chAprEmp.getAprempTypeIdS();
                // 1 评估员上门评估，每人次 100 元
                // 5 评估专家上门评估，每人次 150 元
                String assessCost = aprempTypeIdS == 1 ? "100" : "150";
                chAssessDetailAccounts.setAssessCost(assessCost);
                Long assessAccountsId = saveAssess(aprOrganId, assessCost, srvModeId, evaluateDate);
                if (assessAccountsId != null) {
                    chAssessDetailAccounts.setAssessAccountsId(assessAccountsId);
                    chAssessDetailAccountsMapper.insert(chAssessDetailAccounts);
                }
            }else {
                log.info("{}，该失能人员已进行评估结算，护理人员:{}",chDisableInfo.getApplyId(),person2);
            }
        }


    }

    private Long saveAssess(Integer aprOrganId, String assessCost,Integer modeId,Date evaluateDate) {
        Long assessAccountsId = null;
        AssessIdAndCostVO assessIdAndCostVO = chAssessAccountsMapper.queryAssessByOrganIdAndTime(String.valueOf(aprOrganId), DateUtils.dateToStrYm(evaluateDate),String.valueOf(modeId));
        if(assessIdAndCostVO!=null && assessIdAndCostVO.getAccountsStatus()==2){
            log.info("{},已完成审核，不再进行评估结算",assessIdAndCostVO.getAssessAccountsId());
            return assessAccountsId;
        }
        if (assessIdAndCostVO == null) {
            ChAssessAccounts chAssessAccounts = new ChAssessAccounts();
            chAssessAccounts.setAccountsTime(evaluateDate);
            chAssessAccounts.setAprOrganId(Long.valueOf(aprOrganId));
            chAssessAccounts.setCreationTime(new Date());
            chAssessAccounts.setAccountsStatus((short)1);
            chAssessAccounts.setModeId(modeId);
            chAssessAccounts.setAssessAllCost(new BigDecimal(assessCost));
            chAssessAccountsMapper.insert(chAssessAccounts);
            assessAccountsId =  chAssessAccounts.getAssessAccountsId();
        }else{
            assessAccountsId = assessIdAndCostVO.getAssessAccountsId();
            BigDecimal assessAllCost = assessIdAndCostVO.getAssessAllCost();
            ChAssessAccounts chAssessAccounts = new ChAssessAccounts();
            chAssessAccounts.setAssessAccountsId(assessAccountsId);
            chAssessAccounts.setAssessAllCost(assessAllCost.add(new BigDecimal(assessCost)));
            chAssessAccountsMapper.updateById(chAssessAccounts);
        }
        return assessAccountsId;
    }

    @Override
    public TaskReportVO getReportById(String reportId) {
        TaskReportVO reportById = taskMapper.getReportById(reportId);
        List<ChAprReportFraction> chAprReportFractions = chAprReportFractionMapper.selectList(new LambdaQueryWrapper<ChAprReportFraction>().eq(ChAprReportFraction::getReportId, reportId));
        if(chAprReportFractions.isEmpty()|| chAprReportFractions.size()==0){
            return reportById;
        }
        Map<String, Object> typeHashMap = new HashMap<>();
        for (ChAprReportFraction chAprReportFraction: chAprReportFractions) {
            String taskReportType = chAprReportFraction.getTaskReportType();
            if(!typeHashMap.containsKey(taskReportType)){
                List<ChAprReportFraction> typeList =  chAprReportFractions.stream().filter(c-> c.getTaskReportType().equals(taskReportType)).collect(Collectors.toList());
                Map<String, Object> hashMap = new HashMap<>();
                for (ChAprReportFraction chTaskReportFraction:typeList) {
                    String taskReportProxy = chTaskReportFraction.getTaskReportProxy();
                    if(!hashMap.containsKey(taskReportProxy)){
                        List<ChAprReportFraction> collect = typeList.stream().filter(c->c.getTaskReportProxy().equals(taskReportProxy)).collect(Collectors.toList());
                        hashMap.put(taskReportProxy,collect);
                    }
                }
                typeHashMap.put(taskReportType,hashMap);
                reportById.setChAprReportFractions(typeHashMap);

            }

        }
        return reportById;
    }
    /**
     * 评定报告修改
     */
    @Transactional(rollbackFor = Exception.class)
    @Override
    public void updateReport(ReportUpdateVO vo) {
        Date evaluateDate = null;
        try {
            SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
            evaluateDate = sdf.parse(vo.getEvaluateTime());
        } catch (ParseException e) {
            e.printStackTrace();
        }
        //update鉴定报告
        ChAprReport chAprReport = aprReportMapper.selectById(vo.getReportId());
        chAprReport.setDisableLevelId(vo.getDisableLevelId());
        chAprReport.setPolNo(vo.getPolNo());
        chAprReport.setRemark(vo.getRemark());
        chAprReport.setEvaluateTime(evaluateDate);
        chAprReport.setEvaluateType(vo.getEvaluateType());
        aprReportMapper.updateById(chAprReport);
        // 2023-3-20 新增
        // 更新评定任务状态为已完成，并记录完成时间
        ChAprTask task = new ChAprTask();
        task.setTaskId(chAprReport.getTaskId());
        task.setFinishTime(new Date());
        task.setTaskStatus(3); // 已完成
        taskMapper.updateById(task);
        if(2 == vo.getEvaluateType()){
            ChAprTask chAprTask = taskMapper.selectById(chAprReport.getTaskId());
            Integer disableInfoId = chAprTask.getDisableInfoId();
            taskMapper.insertSrvSend(disableInfoId);
        }

        //附件上传
        this.updateAttachs(vo.getFileDataList(), chAprReport.getReportId().longValue());
        //修改鉴定报告人员(有就update,没有就insert)
        List<ChAprPersonInfo> personInfos = personInfoMapper.selectList(new QueryWrapper<ChAprPersonInfo>().eq("report_id", vo.getReportId()).orderByAsc("info_id"));
        if (vo.getPerson1() != null) {
            if (personInfos.size() >= 1) {
                ChAprPersonInfo personInfo = personInfos.get(0);
                personInfo.setEmpId(vo.getPerson1());
                personInfoMapper.updateById(personInfo);
            } else {
                ChAprPersonInfo personInfo = new ChAprPersonInfo();
                personInfo.setReportId(chAprReport.getReportId());
                personInfo.setEmpId(vo.getPerson1());
                personInfo.setFcd(new Date());
                personInfoMapper.insert(personInfo);
            }
        }
        if (vo.getPerson2() != null) {
            if (personInfos.size() >= 2) {
                ChAprPersonInfo personInfo = personInfos.get(1);
                personInfo.setEmpId(vo.getPerson2());
                personInfoMapper.updateById(personInfo);
            } else {
                ChAprPersonInfo personInfo = new ChAprPersonInfo();
                personInfo.setReportId(chAprReport.getReportId());
                personInfo.setEmpId(vo.getPerson2());
                personInfo.setFcd(new Date());
                personInfoMapper.insert(personInfo);
            }
        }
        if (vo.getPerson3() != null) {
            if (personInfos.size() >= 3) {
                ChAprPersonInfo personInfo = personInfos.get(2);
                personInfo.setEmpId(vo.getPerson3());
                personInfoMapper.updateById(personInfo);
            } else {
                ChAprPersonInfo personInfo = new ChAprPersonInfo();
                personInfo.setReportId(chAprReport.getReportId());
                personInfo.setEmpId(vo.getPerson3());
                personInfo.setFcd(new Date());
                personInfoMapper.insert(personInfo);
            }
        }
        if(!vo.getChAprReportFractions().isEmpty() && vo.getChAprReportFractions().size()>0){
            for (ChAprReportFraction chAprReportFraction: vo.getChAprReportFractions()) {
                chAprReportFraction.setReportId(chAprReport.getReportId());
                if(chAprReportFraction.getChAprReportFractionId()==null){
                    chAprReportFractionMapper.insert(chAprReportFraction);
                }else {
                    chAprReportFractionMapper.updateById(chAprReportFraction);
                }
            }
        }

        // 评估结算
        ReportDetailVO reportDetailVO = new ReportDetailVO();
        reportDetailVO.setCertiCode(vo.getCertiCode());
        reportDetailVO.setPerson1(vo.getPerson1());
        reportDetailVO.setPerson2(vo.getPerson2());
        reportDetailVO.setDisableLevelId(vo.getDisableLevelId());
        reportDetailVO.setEvaluateTime(vo.getEvaluateTime());
        reportDetailVO.setEvaluateType(vo.getEvaluateType());
        assessAccount(reportDetailVO);
    }

    /**
     * 调用feign api来修改附件数据
     */
    private void updateAttachs(List<ChFndAttach> fileDataList, Long ctrlId) {
        // 新增附件修改逻辑
        AttachUpdateVo attachUpdateVo = new AttachUpdateVo();
        attachUpdateVo.setCtrlId(ctrlId);
        attachUpdateVo.setAttachType(AttachType.TASK.getUploadType());
        attachUpdateVo.setChFndAttachs(fileDataList);
        attachFeignService.updateAttachs(attachUpdateVo);
    }

    /**
     * 评定任务分配
     *
     * @param taskId 评定任务id
     * @param empId  评定人员id
     */
    @Transactional(rollbackFor = Exception.class)
    @Override
    public Result<Object> allotTask(String taskId, String empId) {
        ChAprEmp chAprEmp = aprEmpMapper.selectById(empId);
        if (chAprEmp == null || chAprEmp.getGroupLeader() == null || chAprEmp.getGroupLeader() != 0) {
            //不是组长
            return Result.failed("评定人员必须是组长!");
        }
        String[] taskIds = taskId.split(",");
        //任务分配日期
        Date assignTime = new Date();
        for (String id : taskIds) {
            ChAprTask task = taskMapper.selectById(id);
            if (task == null) {
                return Result.failed("无效的taskId!");
            }
            Integer integer = taskMapper.selectReportByTaskId(id);
            if(integer>0){
                return Result.failed("有已分配未进行评定报告录入的单子，请先录入!");
            }
            //更新评定任务信息
            task.setAprOrganId(chAprEmp.getAprOrganId());//鉴定机构id
            task.setAprEmpId(Integer.parseInt(empId));//评定人员id
            task.setAssignTime(assignTime);
            task.setTaskStatus(1);
            taskMapper.updateById(task);
            //更新失能人员信息
            ChDisableInfo chDisableInfo = disableInfoMapper.selectById(task.getDisableInfoId());
            if(chDisableInfo!=null){
                chDisableInfo.setLastTaskId(task.getTaskId());
                disableInfoMapper.updateById(chDisableInfo);
            }

            //插入评定任报告 2023-03-20
            ChAprReport report = new ChAprReport();
            report.setTaskId(task.getTaskId());
            report.setEffTime(new Date());
            report.setFcd(new Date());
            report.setStatus(0);
            aprReportMapper.insert(report);

            ChAprPersonInfo person1Info = new ChAprPersonInfo();
            person1Info.setReportId(report.getReportId());
            if(StringUtils.isNotEmpty(empId)) {
                person1Info.setEmpId(Integer.parseInt(empId));
            }
            person1Info.setFcd(new Date());
            personInfoMapper.insert(person1Info);


            //生成组
            ChAprTaskPush taskPush = new ChAprTaskPush();
            taskPush.setAssignTime(new Date());
            taskPush.setGroupNumber(SerialNumberUtils.getSerialNumber(empId));
            taskPush.setTaskId(Long.parseLong(id));
            taskPush.setEmpId(Long.parseLong(empId));
            taskPush.setStatus((short) 1);
            taskPush.setIsManual((short) 1);
            //生成分组历史
            ChAprTaskPushHis pushHis = new ChAprTaskPushHis();
            BeanUtils.copyProperties(taskPush, pushHis);
            //插入分组数据
            taskPushMapper.insert(taskPush);
            taskPushHisMapper.insert(pushHis);
        }
        return Result.success();
    }

    /**
     * 评定任务分组管理列表
     *
     * @param name      评定人员姓名
     * @param certiCode 评定人员身份证号码
     * @param tel       评定人员手机号码
     */
    @Override
    public List<TaskGroupVO> taskGroupList(String name, String certiCode, String tel) {
        return taskMapper.taskGroupList(name, certiCode, tel);
    }

    /**
     * 查询失能等级列表
     */
    @Override
    public List<ChCfgSrvDisableLevel> cfgSrvDisableLevelList() {
        return cfgSrvDisableLevelMapper.selectList(new QueryWrapper<ChCfgSrvDisableLevel>().orderByDesc("disable_level_id"));
    }

    /**
     * 通过报告id查询评定报告人员信息
     *
     * @param reportId 评定报告id
     */
    @Override
    public List<PersonInfoVO> personInfoList(String reportId) {
        return taskMapper.personInfoList(reportId);
    }

    /**
     * 评定任务分组管理列表详情
     *
     * @param groupNumber 组号
     */
    @Override
    public List<TaskGroupInfoVO> taskGroupInfoList(String groupNumber) {
        return taskMapper.taskGroupInfoList(groupNumber);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public Result<Object> taskGroup(Integer pushId, Integer status, Short refuseReason, String refuseRemark) {
        ChAprTaskPush chAprTaskPush = taskPushMapper.selectById(pushId);
        if (chAprTaskPush == null) {
            return Result.failed("不存在的组!");
        }
        //更新任务组状态
        chAprTaskPush.setStatus(status.shortValue());
        if(refuseReason != null) {
            chAprTaskPush.setRefuseReason(refuseReason);
        }
        if(StringUtils.isNotBlank(refuseRemark)){
            chAprTaskPush.setRefuseRemark(refuseRemark);
        }
        taskPushMapper.updateById(chAprTaskPush);
        //更新评定任务状态
        ChAprTask chAprTask = taskMapper.selectById(chAprTaskPush.getTaskId());
        chAprTask.setTaskStatus(status);
        taskMapper.updateById(chAprTask);
        return Result.success();
    }

    /**
     * 评定任务分组管理(整组操作)
     *
     * @param groupNumber  组号
     * @param status       分组状态 未分配(拒绝(重新分配)):0;已分配:1;已接受:2;已完成:3;拒绝（中止）:4,拒绝（终止）:5
     * @param refuseReason 拒绝原因id
     * @param refuseRemark 拒绝备注
     */
    @Transactional(rollbackFor = Exception.class)
    @Override
    public Result<Object> taskGroupByGroup(String groupNumber, Integer status, Short refuseReason, String refuseRemark) {
        List<ChAprTaskPush> pushList = taskPushMapper.selectList(new QueryWrapper<ChAprTaskPush>().eq("group_number", groupNumber));
        if (pushList == null || pushList.size() <= 0) {
            return Result.failed("不存在的组!");
        }
        short status1 = pushList.get(0).getStatus();
        for (ChAprTaskPush push : pushList) {
            if (status1 != push.getStatus()) {
                return Result.failed("该组状态不一致,不可整组操作!");
            }
        }
        for (ChAprTaskPush push : pushList) {
            //更新任务组状态
            push.setStatus(status.shortValue());
            push.setRefuseReason(refuseReason);
            push.setRefuseRemark(refuseRemark);
            taskPushMapper.updateById(push);
            //更新评定任务状态
            ChAprTask chAprTask = taskMapper.selectById(push.getTaskId());
            chAprTask.setTaskStatus(status);
            taskMapper.updateById(chAprTask);
        }
        return Result.success();
    }

    /**
     * 评定任务分组管理列表详情详情
     *
     * @param pushId 任务组id
     */
    @Override
    public TaskGroupInfoListInfoVO taskGroupInfoListInfo(String pushId) {
        return taskMapper.taskGroupInfoListInfo(pushId);
    }

    /**
     * 分配历史信息列表
     */
    @Override
    public List<AllotTaskHisVO> allotTaskHisList(Integer disabId) {
        return taskMapper.allotTaskHisList(disabId);
    }

    /**
     * 设置预约日期和备注
     *
     * @param pushId   分组id
     * @param timeDate 预约日期
     * @param remark   备注
     */
    @Transactional(rollbackFor = Exception.class)
    @Override
    public Result<Object> updatePushTimeAndRemark(String pushId, Date timeDate, String remark) {
        ChAprTaskPush chAprTaskPush = taskPushMapper.selectById(pushId);
        if (chAprTaskPush == null) {
            return Result.failed("无效的分组id!");
        }
        chAprTaskPush.setTime(timeDate);
        chAprTaskPush.setRefuseRemark(remark);
        int i = taskPushMapper.updateById(chAprTaskPush);
        if (i <= 0) {
            return Result.failed("更新失败!");
        }
        return Result.success();
    }

    @Override
    public List<ChRefuseReason> refuseReasonList() {
        return refuseReasonMapper.selectList(new QueryWrapper<>());
    }

    @Override
    public Result<List<ChFndAttach>> reportFileList(Long reportId) {
        Result<List<ChFndAttach>> listResult = null;
        try {
            // 返回对应的附件列表
            listResult = attachFeignService.selectAttachs(reportId, AttachType.TASK.getUploadType());
            if (!listResult.getCode().equals(ResultCode.SUCCESS.getCode())) {
                log.info("请求获取附件列表错误：错误码{},错误信息:{}", listResult.getCode(), listResult.getMsg());
            }
        } catch (Exception e) {
            log.error(e.getMessage());
            e.printStackTrace();
        }
        return listResult;
    }

    /**
     * 单条任务拒绝
     * @return
     */
    @Override
    public Result<Object> taskRefuseCause(String taskId, String optType, String aprOrganId, String aprEmpId, String optTime, String refuseReason, String refuseRemark, String status, String taskGroupNo, String taskPushId) throws TppesApiException {
        if(taskId != "" && taskId != null){
            ChAprTask task = taskMapper.selectById(taskId);
            if(task != null) {
                task.setTaskStatus(0);
                taskMapper.updateById(task);
                return Result.success();
            }

        }
            return Result.failed();
    }

    /**
     * 开始鉴定
     * @return
     */
    @Override
    public Result<Object> startApprTask(String  taskId,String operationId,String  operationOrganId,String taskGroupNo) throws TppesApiException {
        if(taskId != "" && taskId != null){
            ChAprTask task = taskMapper.selectById(taskId);
            if(task != null) {
                task.setAprType(0);
                taskMapper.updateById(task);
                return Result.success();
            }

        }

        return Result.failed();

    }

    @Override
    public Result<Object> deleteVodFile(String fileId, String taskId) {

        return Result.success();
    }

    @Override
    public int uploadVideo(String taskId, String videoUrl, String videoName, String padUserName, String fileId) {

        return 1;
    }

    @Override
    public List<Map<String, Object>> findReportVideo(String taskId) {
        List<Map<String,Object>> list= new ArrayList<Map<String,Object>>();
        return list;
    }

    /**
     * 查询鉴定任务组信息
     *
     * @return
     * @author fanglg
     */
    @Override
    public List<TaskGroupInfoVO> queryAppraisalInfo(String aprEmpId, String appointStartTime, String appointEndTime, String queryBeginDate, String queryEndDate, String groupNum, Integer pageNo, Integer pageSize) {

        List<TaskGroupInfoVO> taskGroupInfoVOIList = taskMapper.taskGroupInfoList(groupNum);

        return taskGroupInfoVOIList;
    }

    /**
     * 查询鉴定任务组信息
     *
     * @return
     * @author fanglg
     */
    @Override
    public Page<TaskGroupInfoByPageVO> queryAppraisalInfoByPage(String aprEmpId, String appointStartTime, String appointEndTime, String queryBeginDate, String queryEndDate, String groupNum, Integer pageNo, Integer pageSize) {

        Page<TaskGroupInfoByPageVO> taskGroupInfoVOIList = taskMapper.taskGroupInfoListByPage( aprEmpId, appointStartTime, appointEndTime, queryBeginDate, queryEndDate, groupNum, pageNo, pageSize);

        return taskGroupInfoVOIList;
    }

    /**
     * 获取鉴定报告详情
     * @return
     */
    @Override
    public ChAprReport taskReportDetails(String  taskId) throws TppesApiException {
        LambdaQueryWrapper<ChAprReport> wrapper = Wrappers.lambdaQuery();
        wrapper.eq(ChAprReport::getTaskId,taskId);
        ChAprReport chAprReport = aprReportMapper.selectOne(wrapper);

        return chAprReport;
    }

    /**
     * 单条任务详情
     * @return
     */
    @Override
    public ChAprTask singleTaskDetails(String taskId, String taskGroupNo, String taskPushId) throws TppesApiException {
        LambdaQueryWrapper<ChAprTask> wrapper = Wrappers.lambdaQuery();
        wrapper.eq(ChAprTask::getTaskId,taskId);
        ChAprTask aprTask = taskMapper.selectOne(wrapper);

        return aprTask;
    }

    /**
     * 无锡单条任务详情
     * @return
     */
    @Override
    public ChAprTask singleTaskDetailsWuXi(String taskId, String taskGroupNo, String taskPushId) throws TppesApiException {
        LambdaQueryWrapper<ChAprTask> wrapper = Wrappers.lambdaQuery();
        wrapper.eq(ChAprTask::getTaskId,taskId);
        ChAprTask aprTask = taskMapper.selectOne(wrapper);

        return aprTask;
    }



    /**
     * 获取无锡鉴定报告详情
     * @return
     */
    @Override
    public ChAprReport queryAprReportForWUXI(String taskId) throws TppesApiException {
        LambdaQueryWrapper<ChAprReport> wrapper = Wrappers.lambdaQuery();
        wrapper.eq(ChAprReport::getTaskId,taskId);
        ChAprReport chAprReport = aprReportMapper.selectOne(wrapper);

        return chAprReport;
    }

    /**
     * 鉴定人员鉴定任务详情获取
     * @return
     */
    @Override
    public IPage<ChAprTask> apprTaskDetailInfo(String appointStartTime,String appointEndTime,String status,String taskGroupNo,Integer pageNo,Integer pageSize) throws TppesApiException {
        LambdaQueryWrapper<ChAprTask> wrapper = Wrappers.lambdaQuery();
        /*if(appointStartTime!=null && !"".equals(appointStartTime)){
            wrapper.gt("appointStartTime",appointStartTime);
        }
        if(appointEndTime!=null && !"".equals(appointEndTime)){
            wrapper.lt("appointEndTime",appointEndTime);
        }
        if(status!=null && !"".equals(status)){
            wrapper.eq("status",status);
        }
        wrapper.eq("taskGroupNo",taskGroupNo);*/
        Page<ChAprTask> page = new Page<>(pageNo , pageSize , false);
        IPage<ChAprTask> chAprTaskPage = taskMapper.selectPage(page,wrapper);

        return chAprTaskPage;

    }

    @Override
    public Map taskReportFractionDtlQueryList() {
        LambdaQueryWrapper<ChTaskReportFractionDtl> lwq = new LambdaQueryWrapper<>();
        lwq.orderBy(true,true,ChTaskReportFractionDtl::getTaskReportFractionId);
        List<ChTaskReportFractionDtl> chTaskReportFractionDtls = chTaskReportFractionDtlMapper.selectList(lwq);

        Map<String, Object> typeHashMap = new LinkedHashMap<>();
        for (ChTaskReportFractionDtl chTaskReportFractionDtl : chTaskReportFractionDtls) {
            String taskReportType = chTaskReportFractionDtl.getTaskReportType();
            if(!typeHashMap.containsKey(taskReportType)){
                List<ChTaskReportFractionDtl> typeList =  chTaskReportFractionDtls.stream().filter(c-> c.getTaskReportType().equals(taskReportType)).collect(Collectors.toList());
                Map<String, Object> hashMap = new LinkedHashMap<>();
                for (ChTaskReportFractionDtl chTaskReportFraction:typeList) {
                    String taskReportProxy = chTaskReportFraction.getTaskReportProxy();
                    if(!hashMap.containsKey(taskReportProxy)){
                        List<ChTaskReportFractionDtl> collect = typeList.stream().filter(c->c.getTaskReportProxy().equals(taskReportProxy)).collect(Collectors.toList());
                        hashMap.put(taskReportProxy,collect);
                    }
                }
                typeHashMap.put(taskReportType,hashMap);
            }
        };
        return typeHashMap;
    }




    @Override
    public Workbook assessAccountExport(String assessAccountsId) {
        List<AssessAccountsExportResp> assessAccountExportList = chAssessDetailAccountsMapper.assessAccountDetailExport(assessAccountsId);
        ExportParams exportParams = new ExportParams();
        exportParams.setType(ExcelType.XSSF);   //对应xlsx
        Workbook workbook = ExcelExportUtil.exportExcel(exportParams, AssessAccountsExportResp.class, assessAccountExportList);
        return workbook;
    }

    @Override
    public List<ChAssessDetailAccountsResp> queryAssessAccountsDetail(String assessAccountsId) {
        return chAssessDetailAccountsMapper.queryAssessAccountsDetail(assessAccountsId);
    }


    @Override
    @Transactional(rollbackFor=Exception.class)
    public int updateChAssessAccounts(int id) {
        ChAssessAccounts ca = new ChAssessAccounts();
        ca.setAssessAccountsId(Long.valueOf(id));
        ca.setAccountsStatus((short) 2);
        return chAssessAccountsMapper.updateById(ca);
    }



    @Override
    public Page<AssessAccountsListResp> searchAssessAccountsList(SrvOrganListReq srvOrganListReq) {
       // List<Long> organIds = baseAccountService.getOrganIds(srvOrganListReq.getOrganId(), srvOrganListReq.getIsInvolveChild());
        return chAssessAccountsMapper.searchAssessAccountList(new Page<>(srvOrganListReq.getPageNum(), srvOrganListReq.getPageSize()), null, srvOrganListReq);
    }


}
