package com.hungraim.ltc.controller;

import com.alibaba.fastjson.JSONObject;
import com.hungraim.ltc.util.CsoftSecurityUtil;
import com.hungraim.ltc.util.Result;
import com.hungraim.ltc.util.ResultCode;
import lombok.AllArgsConstructor;
import lombok.SneakyThrows;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.security.jwt.JwtHelper;
import org.springframework.security.oauth2.common.OAuth2AccessToken;
import org.springframework.security.oauth2.provider.endpoint.TokenEndpoint;
import org.springframework.web.bind.annotation.*;

import java.security.Principal;
import java.util.Map;

/**
 * 认证中心
 *
 * @author hubin
 */
@RestController
@RequestMapping("/oauth")
@AllArgsConstructor
public class AuthController {


  final static String FALSE="false";
  private final RedisTemplate redisTemplate;
  private final TokenEndpoint tokenEndpoint;

  @Autowired
  private CsoftSecurityUtil csoftSecurityUtil;


  @PostMapping("/token")
  @SneakyThrows
  public Result<OAuth2AccessToken> postAccessToken(Principal principal, @RequestParam Map<String, String> parameters,String publicKeyString)  {
    String password = parameters.get("password");
    if(FALSE.equals(password)){
      return Result.failed(ResultCode.USER_LOGIN_ERROR);
    }
    String decrypt = csoftSecurityUtil.decryptRSADefault(password,publicKeyString);
    parameters.put("password", decrypt);
    OAuth2AccessToken oAuth2AccessToken = tokenEndpoint.postAccessToken(principal, parameters).getBody();
    return Result.success(oAuth2AccessToken);
  }

  /**
   * 获取公钥
   * @return
   */
  @GetMapping("/genKeyPair")
  public Result<String> genKeyPair() {
    Map keyMap = csoftSecurityUtil.createKeyPairs();
    return Result.success(keyMap.get(0).toString());
  }

  @PostMapping("/logout")
  public Result doLogout(String access_token){
    String claims = JwtHelper.decode(access_token).getClaims();
    String jti = (String)JSONObject.parseObject(claims).get("jti");
    redisTemplate.opsForValue().set(jti,access_token);
    return Result.success();
  }

}
