package com.hungraim.ltc.governance.service.impl;

import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.hungraim.ltc.api.SrvModeFeignService;
import com.hungraim.ltc.governance.dao.*;
import com.hungraim.ltc.governance.service.NursingServiceItemsService;
import com.hungraim.ltc.pojo.entity.SysConfig.ChCfgSrvMode;
import com.hungraim.ltc.pojo.entity.disable.ChCfgSrvDisableLevel;
import com.hungraim.ltc.pojo.entity.disable.ChFndDiseaseType;
import com.hungraim.ltc.pojo.entity.disable.ChServiceType;
import com.hungraim.ltc.pojo.entity.disable.ChServiceTypeDetailed;
import com.hungraim.ltc.pojo.entity.serviceManage.ChSrvOrganProject;
import com.hungraim.ltc.pojo.vo.disable.ChServiceTypeVo;
import com.hungraim.ltc.pojo.vo.disable.SrvModeVo;
import com.hungraim.ltc.pojo.vo.governance.OrganProjectVO;
import com.hungraim.ltc.util.Result;
import lombok.AllArgsConstructor;
import org.apache.commons.lang.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Date;
import java.util.List;

@Service
@AllArgsConstructor
public class NursingServiceItemsServiceImpl implements NursingServiceItemsService {

    private final ChSrvOrganProjectMapper chSrvOrganProjectMapper;
    private final DisableLevelMapper disableLevelMapper;
    private final SrvModeMapper srvModeMapper;
    private final SrvModeFeignService srvModeFeignService;
    private final ServiceTypeMapper serviceTypeMapper;
    private final ServiceTypeDetailedMapper serviceTypeDetailedMapper;
    private final FndDiseaseTypeMapper fndDiseaseTypeMapper;

    @Override
    public Page<OrganProjectVO> organProjectList(Page<OrganProjectVO> page, String srvOrganId,String organId, String name, String status) {
        Page<OrganProjectVO> organProjectVOPage;
        if(organId.equals("0") || organId==null){
            organProjectVOPage = chSrvOrganProjectMapper.organProjectList(page, null, null, name, status);
        }else{
            organProjectVOPage= chSrvOrganProjectMapper.organProjectList(page, srvOrganId, organId, name, status);
        }
        return organProjectVOPage;
    }

    @Override
    public void organProjectConfig(ChSrvOrganProject project,int type) {
        if(type ==3){
            ChSrvOrganProject chSrvOrganProject = new ChSrvOrganProject();
            chSrvOrganProject.setStatus((short) 1);
            UpdateWrapper<ChSrvOrganProject> updateWrapper = new UpdateWrapper<ChSrvOrganProject>();
            updateWrapper.eq("PROJECT_ID",project.getProjectId());
            chSrvOrganProjectMapper.update(chSrvOrganProject,updateWrapper);
        }else{
            if (project.getProjectId() != null) {
                chSrvOrganProjectMapper.updateById(project);
            } else {
                project.setEffTime(new Date());//创建时间
                chSrvOrganProjectMapper.insert(project);
            }
        }

    }

    @Override
    public void disableLevelConfig(String disableLevelId, String disableLevelName, Short disableLevelStartValue, Short disableLevelEndValue, String disableLevelRemark) {
        if (StringUtils.isNotBlank(disableLevelId)) {
            ChCfgSrvDisableLevel chCfgSrvDisableLevel = disableLevelMapper.selectById(disableLevelId);
            chCfgSrvDisableLevel.setDisableLevelName(disableLevelName);
            chCfgSrvDisableLevel.setStartValue(disableLevelStartValue);
            chCfgSrvDisableLevel.setEndValue(disableLevelEndValue);
            chCfgSrvDisableLevel.setRemark(disableLevelRemark);
            disableLevelMapper.updateById(chCfgSrvDisableLevel);
        } else {
            ChCfgSrvDisableLevel chCfgSrvDisableLevel = new ChCfgSrvDisableLevel();
            chCfgSrvDisableLevel.setDisableLevelName(disableLevelName);
            chCfgSrvDisableLevel.setStartValue(disableLevelStartValue);
            chCfgSrvDisableLevel.setEndValue(disableLevelEndValue);
            chCfgSrvDisableLevel.setRemark(disableLevelRemark);
            disableLevelMapper.insert(chCfgSrvDisableLevel);
        }
    }

    @Override
    public void modeConfig(String modeId, String modeName, String modeRemark) {
        if (StringUtils.isNotBlank(modeId)) {
            ChCfgSrvMode chCfgSrvMode = srvModeMapper.selectById(modeId);
            chCfgSrvMode.setModeName(modeName);
            chCfgSrvMode.setRemark(modeRemark);
            srvModeMapper.updateById(chCfgSrvMode);
        } else {
            ChCfgSrvMode chCfgSrvMode = new ChCfgSrvMode();
            chCfgSrvMode.setModeName(modeName);
            chCfgSrvMode.setRemark(modeRemark);
            srvModeMapper.insert(chCfgSrvMode);
        }
    }

    @Override
    public List<ChCfgSrvDisableLevel> disableLevelConfigList() {
        return disableLevelMapper.selectList(new QueryWrapper<ChCfgSrvDisableLevel>().orderByDesc("disable_level_id"));
    }

    @Override
    public List<SrvModeVo> modeConfigList() {
        Result<List<SrvModeVo>> listResult = srvModeFeignService.cfgSrvMode();
        if ("00000".equals(listResult.getCode())) {
            return listResult.getData();
        }
        return null;
    }

    @Override
    public void delectDisableLevel(Long disableLevelId) {
        disableLevelMapper.deleteById(disableLevelId);
    }

    @Override
    public void deleteSrvModel(Long modeId) {
        srvModeMapper.deleteById(modeId);
    }

    @Override
    public List<ChServiceTypeVo> queryServiceTypeList() {
        List<ChServiceType> list = serviceTypeMapper.selectList(new QueryWrapper<>());
        List<ChServiceTypeVo> chServiceTypeVoList = new ArrayList<ChServiceTypeVo>();
        for(ChServiceType chServiceType : list){
            if(chServiceType.getParaId() == 0L){
                ChServiceTypeVo chServiceTypeVo = new ChServiceTypeVo();
                chServiceTypeVo.setServiceTypeId(chServiceType.getServiceTypeId());
                chServiceTypeVo.setServiceTypeName(chServiceType.getServiceTypeName());
                QueryWrapper<ChServiceTypeDetailed> wrapper = new QueryWrapper<ChServiceTypeDetailed>();
                wrapper.eq("para_id", chServiceType.getServiceTypeId());
                List<ChServiceTypeDetailed> detailedList = serviceTypeDetailedMapper.selectList(wrapper);
                chServiceTypeVo.setList(detailedList);
                chServiceTypeVoList.add(chServiceTypeVo);
            }
        }
        return chServiceTypeVoList;
    }

    @Override
    public List<ChFndDiseaseType> fndAllDisease() {
        QueryWrapper<ChFndDiseaseType> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("IS_VALID", "0");
        queryWrapper.orderByAsc("DISE_TYPE_ID");
        return fndDiseaseTypeMapper.selectList(queryWrapper);
    }

    @Override
    public List<ChFndDiseaseType> fndDiseaseList(String parDiseTypeId) {
        QueryWrapper<ChFndDiseaseType> queryWrapper = new QueryWrapper<>();
        //queryWrapper.eq("IS_VALID", "0");
        if (StringUtils.isNotBlank(parDiseTypeId)) {
            queryWrapper.eq("PAR_DISE_TYPE_ID", parDiseTypeId);
        } else {
            queryWrapper.and(wrapper -> wrapper.isNull("PAR_DISE_TYPE_ID").or().eq("PAR_DISE_TYPE_ID", ""));
        }
        return fndDiseaseTypeMapper.selectList(queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void saveDisease(List<ChFndDiseaseType> chFndDiseaseTypes){
        //遍历修改的列表
        chFndDiseaseTypes.stream().forEach(e->{
            if(e.getDiseTypeId() == null){
                fndDiseaseTypeMapper.insert(e);
            }else{
                fndDiseaseTypeMapper.updateById(e);
            }
        });

    }

}
